@@ -21,7 +21,7 @@
 #ifndef AKREGATOR_AKREGATOREXPORT_H
 #define AKREGATOR_AKREGATOREXPORT_H
 
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 #define AKREGATOR_EXPORT KDE_EXPORT
 
