@@ -34,7 +34,7 @@ namespace RSS
 	 */
 	class KDE_EXPORT DataRetriever : public TQObject
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 		public:
 			/**
@@ -89,7 +89,7 @@ namespace RSS
 	 */
 	class KDE_EXPORT FileRetriever : public DataRetriever
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 		public:
 			/**
@@ -161,7 +161,7 @@ namespace RSS
 	 */
 	class OutputRetriever : public DataRetriever
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 		public:
 			/**
@@ -256,7 +256,7 @@ namespace RSS
 	 */
 	class KDE_EXPORT Loader : public TQObject
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 		friend class someClassWhichDoesNotExist;
 		public:
