@@ -56,7 +56,7 @@ class TQStringList;
 namespace Kleo {
 
   class KDE_EXPORT KeyApprovalDialog : public KDialogBase {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     struct Item {
