@@ -1170,7 +1170,7 @@ void KcmSambaConf::addSambaUserBtnClicked()
   {
     SambaUser user( item->text(0), item->text(1).toInt() );
     
-    TQCString password;
+    TQString password;
     int passResult = KPasswordDialog::getNewPassword(password, 
                         i18n("<qt>Please enter a password for the user <b>%1</b></qt>").arg(user.name));
     if (passResult != KPasswordDialog::Accepted) {
@@ -1233,7 +1233,7 @@ void KcmSambaConf::sambaUserPasswordBtnClicked()
   {
     SambaUser user( item->text(0), item->text(1).toInt() );
     
-    TQCString password;
+    TQString password;
     int passResult = KPasswordDialog::getNewPassword(password,
                         i18n("Please enter a password for the user %1").arg(user.name));
     if (passResult != KPasswordDialog::Accepted)
