@@ -22,7 +22,7 @@ class FileRenamerWidget;
 
 class FileRenamerConfigDlg : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
     FileRenamerConfigDlg(TQWidget *parent);
