@@ -44,6 +44,8 @@
 
 #undef KeyRelease
 
+#define TStringToTQString(s) TQString::fromUtf8((s).toCString(true))
+
 using namespace ActionCollection;
 
 class FileNameValidator : public TQValidator
@@ -403,7 +405,7 @@ void TagEditor::updateCollection()
     TagLib::StringList genres = TagLib::ID3v1::genreList();
 
     for(TagLib::StringList::ConstIterator it = genres.begin(); it != genres.end(); ++it)
-	genreHash.insert(TStringToQString((*it)));
+	genreHash.insert(TStringToTQString((*it)));
 
     m_genreList = genreHash.values();
     m_genreList.sort();
@@ -436,7 +438,7 @@ void TagEditor::readConfig()
     TagLib::StringList genres = TagLib::ID3v1::genreList();
 
     for(TagLib::StringList::ConstIterator it = genres.begin(); it != genres.end(); ++it)
-	m_genreList.append(TStringToQString((*it)));
+	m_genreList.append(TStringToTQString((*it)));
     m_genreList.sort();
 
     m_genreBox->clear();
@@ -767,7 +769,7 @@ void TagEditor::showEvent(TQShowEvent *e)
 bool TagEditor::eventFilter(TQObject *watched, TQEvent *e)
 {
     TQKeyEvent *ke = TQT_TQKEYEVENT(e);
-    if(watched->inherits(TQSPINBOX_OBJECT_NAME_STRING) && e->type() == TQEvent::KeyRelease && ke->state() == 0)
+    if(watched->inherits("TQSpinBox") && e->type() == TQEvent::KeyRelease && ke->state() == 0)
 	slotDataChanged();
 
     return false;
