@@ -510,7 +510,7 @@ void MessageWin::initView()
 	mOkButton = new KPushButton(KStdGuiItem::close(), topWidget);
 	// Prevent accidental acknowledgement of the message if the user is typing when the window appears
 	mOkButton->clearFocus();
-	mOkButton->setFocusPolicy(TQ_ClickFocus);    // don't allow keyboard selection
+	mOkButton->setFocusPolicy(TQWidget::ClickFocus);    // don't allow keyboard selection
 	mOkButton->setFixedSize(mOkButton->sizeHint());
 	connect(mOkButton, TQT_SIGNAL(clicked()), TQT_SLOT(close()));
 	grid->addWidget(mOkButton, 0, gridIndex++, AlignHCenter);
@@ -520,7 +520,7 @@ void MessageWin::initView()
 	{
 		// Edit button
 		mEditButton = new TQPushButton(i18n("&Edit..."), topWidget);
-		mEditButton->setFocusPolicy(TQ_ClickFocus);    // don't allow keyboard selection
+		mEditButton->setFocusPolicy(TQWidget::ClickFocus);    // don't allow keyboard selection
 		mEditButton->setFixedSize(mEditButton->sizeHint());
 		connect(mEditButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotEdit()));
 		grid->addWidget(mEditButton, 0, gridIndex++, AlignHCenter);
@@ -531,7 +531,7 @@ void MessageWin::initView()
 	{
 		// Defer button
 		mDeferButton = new TQPushButton(i18n("&Defer..."), topWidget);
-		mDeferButton->setFocusPolicy(TQ_ClickFocus);    // don't allow keyboard selection
+		mDeferButton->setFocusPolicy(TQWidget::ClickFocus);    // don't allow keyboard selection
 		mDeferButton->setFixedSize(mDeferButton->sizeHint());
 		connect(mDeferButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotDefer()));
 		grid->addWidget(mDeferButton, 0, gridIndex++, AlignHCenter);
