@@ -712,7 +712,7 @@ void RecurrenceEdit::enableExceptionButtons()
 		mChangeExceptionButton->setEnabled(enable);
 
 	// Prevent the exceptions list box receiving keyboard focus is it's empty
-	mExceptionDateList->setFocusPolicy(mExceptionDateList->count() ? TQ_WheelFocus : TQ_NoFocus);
+	mExceptionDateList->setFocusPolicy(mExceptionDateList->count() ? TQWidget::WheelFocus : TQWidget::NoFocus);
 }
 
 /******************************************************************************
