@@ -389,7 +389,7 @@ void DetailedInfoDlg::reloadContent()
 	if ( TQFile::exists( picpath ) )
 	{
 		TQImage img( picpath, "JPEG" );
-		img = img.smoothScale ( 400, 400, TQ_ScaleMin );
+		img = img.smoothScale ( 400, 400, TQImage::ScaleMin );
 		TQPixmap pic;
 		pic.convertFromImage( img );
 		piclabel->setPixmap( pic );
