@@ -192,9 +192,9 @@ bool KatePrinter::print (KateDocument *doc)
 
          tags["d"] = TDEGlobal::locale()->formatDateTime(dt, true, false);
          tags["D"] =  TDEGlobal::locale()->formatDateTime(dt, false, false);
-         tags["h"] =  TDEGlobal::locale()->formatTime(TQT_TQTIME_OBJECT(dt.time()), false);
-         tags["y"] =  TDEGlobal::locale()->formatDate(TQT_TQDATE_OBJECT(dt.date()), true);
-         tags["Y"] =  TDEGlobal::locale()->formatDate(TQT_TQDATE_OBJECT(dt.date()), false);
+         tags["h"] =  TDEGlobal::locale()->formatTime(dt.time(), false);
+         tags["y"] =  TDEGlobal::locale()->formatDate(dt.date(), true);
+         tags["Y"] =  TDEGlobal::locale()->formatDate(dt.date(), false);
          tags["f"] =  doc->url().fileName();
          tags["U"] =  doc->url().prettyURL();
          if ( selectionOnly )
