@@ -446,7 +446,7 @@ bool KateSuperRange::boundaryOn(uint lineNum) const
 
 void KateSuperRange::slotEvaluateChanged()
 {
-  if (sender() == static_cast<TQObject*>(m_start)) {
+  if (sender() == m_start) {
     if (m_evaluate) {
       if (!m_endChanged) {
         // Only one was changed
@@ -484,7 +484,7 @@ void KateSuperRange::slotEvaluateChanged()
 
 void KateSuperRange::slotEvaluateUnChanged()
 {
-  if (sender() == static_cast<TQObject*>(m_start)) {
+  if (sender() == m_start) {
     if (m_evaluate) {
       if (m_endChanged) {
         // Only one changed
@@ -636,7 +636,7 @@ bool KateSuperRangeList::rangesInclude(const KateTextCursor& cursor)
 void KateSuperRangeList::slotEliminated()
 {
   if (sender()) {
-    KateSuperRange* range = static_cast<KateSuperRange*>(const_cast<TQObject*>(TQT_TQOBJECT_CONST(sender())));
+    KateSuperRange* range = static_cast<KateSuperRange*>(const_cast<TQObject*>(sender()));
     emit rangeEliminated(range);
 
     if (m_trackingBoundaries) {
