@@ -2438,7 +2438,7 @@ bool KateViewInternal::isTargetSelected( const TQPoint& p )
 
 bool KateViewInternal::eventFilter( TQObject *obj, TQEvent *e )
 {
-  if (TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(m_lineScroll))
+  if (obj == m_lineScroll)
   {
     // the second condition is to make sure a scroll on the vertical bar doesn't cause a horizontal scroll ;)
     if (e->type() == TQEvent::Wheel && m_lineScroll->minValue() != m_lineScroll->maxValue())
@@ -3263,27 +3263,44 @@ void KateViewInternal::clear()
 
 void KateViewInternal::wheelEvent(TQWheelEvent* e)
 {
-  if (m_lineScroll->minValue() != m_lineScroll->maxValue() && e->orientation() != Qt::Horizontal) {
-    // React to this as a vertical event
-    if ( ( e->state() & ControlButton ) || ( e->state() & ShiftButton ) ) {
-      if (e->delta() > 0)
-        scrollPrevPage();
-      else
-        scrollNextPage();
-    } else {
-      scrollViewLines(-((e->delta() / 120) * TQApplication::wheelScrollLines()));
-      // maybe a menu was opened or a bubbled window title is on us -> we shall erase it
-      update();
-      leftBorder->update();
-    }
+	if (e->state() & ControlButton)
+	{
+		if (e->delta() > 0)
+		{
+			slotIncFontSizes();
+		}
+		else
+		{
+			slotDecFontSizes();
+		}
+	}
+	else
+	{
+		if (m_lineScroll->minValue() != m_lineScroll->maxValue() && e->orientation() != Qt::Horizontal)
+		{
+			// React to this as a vertical event
+			if ( e->state() & ShiftButton )
+			{
+				if (e->delta() > 0)
+					scrollPrevPage();
+				else
+					scrollNextPage();
+			}
+			else
+			{
+				scrollViewLines(-((e->delta() / 120) * TQApplication::wheelScrollLines()));
+				// maybe a menu was opened or a bubbled window title is on us -> we shall erase it
+				update();
+				leftBorder->update();
+			}
+		} else if (columnScrollingPossible()) {
+			TQWheelEvent copy = *e;
+			TQApplication::sendEvent(m_columnScroll, &copy);
 
-  } else if (columnScrollingPossible()) {
-    TQWheelEvent copy = *e;
-    TQApplication::sendEvent(m_columnScroll, &copy);
-
-  } else {
-    e->ignore();
-  }
+		} else {
+			e->ignore();
+		}
+	}
 }
 
 void KateViewInternal::startDragScroll()
