@@ -7,14 +7,14 @@ class TDEAboutData;
 
 class DbSeFactory : public KLibFactory
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	DbSeFactory( TQObject *parent=0, const char *name=0);
 	~DbSeFactory();
 
 	virtual TQObject *createObject( TQObject *parent=0, const char *name=0,
-	                               const char *classname=TQOBJECT_OBJECT_NAME_STRING,
+	                               const char *classname="TQObject",
 	                               const TQStringList &args = TQStringList());
 
 	static TDEInstance *instance();
