@@ -1115,14 +1115,12 @@ bool KBgEngineFIBS::queryConnection(const bool newlogin)
 
 		first = true;
 		do {
-			TQCString password;
 			if (newlogin)
-				ret = (KPasswordDialog::getNewPassword(password, text) == KPasswordDialog::Accepted);
+				ret = (KPasswordDialog::getNewPassword(msg, text) == KPasswordDialog::Accepted);
 			else
-				ret = (KPasswordDialog::getPassword(password, text) == KPasswordDialog::Accepted);
+				ret = (KPasswordDialog::getPassword(msg, text) == KPasswordDialog::Accepted);
 
-			password.stripWhiteSpace();
-			msg = password;
+			msg.stripWhiteSpace();
 
 			if (first) {
 				text += i18n("The password may not contain colons or spaces!");
