@@ -62,7 +62,7 @@ MainQtWidget::MainQtWidget()
 
 	// we split the main view into 2 parts, one for the tasks, one for the
 	// statistics
-	TQSplitter* splitter = new TQSplitter(Qt::Horizontal, this,TQSPLITTER_OBJECT_NAME_STRING);
+	TQSplitter* splitter = new TQSplitter(Qt::Horizontal, this,"TQSplitter");
 	setCentralWidget(splitter);
 
 	// the iconlist, where the user can choose the different exercises
