@@ -371,7 +371,7 @@ DeleteCommand::DeleteCommand( const TQString &n, FormWindow *fw,
 
     // Include the children of the selected items when deleting
     for ( TQWidget *w = widgets.first(); w; w = widgets.next() ) {
-	TQObjectList *children = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
+	TQObjectList *children = w->queryList( "TQWidget" );
 	for ( TQWidget *c = (TQWidget *)children->first(); c; c = (TQWidget *)children->next() ) {
 	    if ( copyOfWidgets.find( c ) == -1 && formWindow()->widgets()->find( c ) ) {
 		widgets.insert(widgets.at() + 1, c);
@@ -1128,7 +1128,7 @@ void AddConnectionCommand::execute()
 {
     MetaDataBase::addConnection( TQT_TQOBJECT(formWindow()), connection.sender,
 				 connection.signal, connection.receiver, connection.slot );
-    if ( TQT_BASE_OBJECT(connection.receiver) == TQT_BASE_OBJECT(formWindow()->mainContainer()) )
+    if ( connection.receiver == formWindow()->mainContainer() )
 	formWindow()->mainWindow()->propertyeditor()->eventList()->setup();
 }
 
@@ -1136,7 +1136,7 @@ void AddConnectionCommand::unexecute()
 {
     MetaDataBase::removeConnection( TQT_TQOBJECT(formWindow()), connection.sender,
 				    connection.signal, connection.receiver, connection.slot );
-    if ( TQT_BASE_OBJECT(connection.receiver) == TQT_BASE_OBJECT(formWindow()->mainContainer()) )
+    if ( connection.receiver == formWindow()->mainContainer() )
 	formWindow()->mainWindow()->propertyeditor()->eventList()->setup();
 }
 
@@ -1152,7 +1152,7 @@ void RemoveConnectionCommand::execute()
 {
     MetaDataBase::removeConnection( TQT_TQOBJECT(formWindow()), connection.sender,
 				    connection.signal, connection.receiver, connection.slot );
-    if ( TQT_BASE_OBJECT(connection.receiver) == TQT_BASE_OBJECT(formWindow()->mainContainer()) )
+    if ( connection.receiver == formWindow()->mainContainer() )
 	formWindow()->mainWindow()->propertyeditor()->eventList()->setup();
 }
 
@@ -1160,7 +1160,7 @@ void RemoveConnectionCommand::unexecute()
 {
     MetaDataBase::addConnection( TQT_TQOBJECT(formWindow()), connection.sender,
 				 connection.signal, connection.receiver, connection.slot );
-    if ( TQT_BASE_OBJECT(connection.receiver) == TQT_BASE_OBJECT(formWindow()->mainContainer()) )
+    if ( connection.receiver == formWindow()->mainContainer() )
 	formWindow()->mainWindow()->propertyeditor()->eventList()->setup();
 }
 
