@@ -152,7 +152,7 @@ MenuBarEditor::MenuBarEditor( FormWindow * fw, TQWidget * parent, const char * n
       hasSeparator( FALSE )
 {
     setAcceptDrops( TRUE );
-    setFocusPolicy( TQ_StrongFocus );
+    setFocusPolicy( TQWidget::StrongFocus );
 
     addItem.setMenuText( i18n("new menu") );
     addSeparator.setMenuText( i18n("new separator") );
@@ -571,7 +571,7 @@ void MenuBarEditor::paste()
 
 bool MenuBarEditor::eventFilter( TQObject * o, TQEvent * e )
 {
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(lineEdit) && e->type() == TQEvent::FocusOut ) {
+    if ( o == lineEdit && e->type() == TQEvent::FocusOut ) {
 	leaveEditMode();
 	lineEdit->hide();
 	update();
