@@ -140,7 +140,7 @@ QueryView::QueryView(TQWidget *_parent)
   part->setJScriptEnabled(false);
   part->setJavaEnabled(false);
   part->setURLCursor(KCursor::handCursor());
-  setFocusPolicy(TQ_NoFocus);
+  setFocusPolicy(TQWidget::NoFocus);
   connect(part, TQT_SIGNAL(completed()), TQT_SLOT(partCompleted()));
   connect(part, TQT_SIGNAL(middleButtonClicked()), TQT_SLOT(middleButtonClicked()));
   rightBtnMenu = new TDEPopupMenu(this);
