@@ -109,7 +109,7 @@ KGVPart::KGVPart( TQWidget* parentWidget, const char*,
 
     // Setup main widget
     _mainWidget = new KGVMainWidget( parentWidget );
-    _mainWidget->setFocusPolicy( TQ_StrongFocus );
+    _mainWidget->setFocusPolicy( TQWidget::StrongFocus );
     _mainWidget->installEventFilter( this );
     _mainWidget->setAcceptDrops( true );
     connect( _mainWidget, TQT_SIGNAL( spacePressed() ),
@@ -1032,6 +1032,3 @@ void KGVPart::showPopup( int, int, const TQPoint& pos )
 }
 
 #include "kgv_view.moc"
-
-
-// vim:sw=4:sts=4:ts=8:sta:tw=78:noet
