@@ -26,6 +26,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <assert.h>
 
+#ifdef Q_OS_SOLARIS
+#include <procfs.h>
+#endif /* SunOS */
+
 #include <tqbitmap.h>
 #include <tqcolor.h>
 #include <tqcursor.h>
@@ -62,8 +66,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "taskcontainer.h"
 #include "taskcontainer.moc"
 
-#define READ_MERGED_TASBKAR_SETTING(x) ((m_settingsObject->useGlobalSettings())?m_globalSettingsObject->x():m_settingsObject->x())
-#define READ_MERGED_TASBKAR_ACTION(x) ((m_settingsObject->useGlobalSettings())?m_globalSettingsObject->action(x):m_settingsObject->action(x))
+#define READ_MERGED_TASKBAR_SETTING(x) ((m_settingsObject->useGlobalSettings())?m_globalSettingsObject->x():m_settingsObject->x())
+#define READ_MERGED_TASKBAR_ACTION(x) ((m_settingsObject->useGlobalSettings())?m_globalSettingsObject->action(x):m_settingsObject->action(x))
 
 static Bool netwm_atoms_created = False;
 static Atom net_wm_pid = 0;
@@ -96,6 +100,18 @@ static void create_atoms(Display *d) {
 }
 
 bool is_process_resumable(pid_t pid) {
+#ifdef Q_OS_SOLARIS
+	TQFile procStatFile(TQString("/proc/%1/lwp/1/lwpsinfo").arg(pid));
+	if (procStatFile.open(IO_ReadOnly)) {
+		TQByteArray statRaw = procStatFile.readAll();
+		lwpsinfo_t *inf = (lwpsinfo_t *)statRaw.data();
+
+		procStatFile.close();
+		if( inf->pr_sname == 'T' ) {
+			return true;
+		}
+	}
+#else /* default */
 	TQFile procStatFile(TQString("/proc/%1/stat").arg(pid));
 	if (procStatFile.open(IO_ReadOnly)) {
 		TQByteArray statRaw = procStatFile.readAll();
@@ -107,13 +123,9 @@ bool is_process_resumable(pid_t pid) {
 		if( state == "T" ) {
 			return true;
 		}
-		else {
-			return false;
-		}
-	}
-	else {
-		return false;
 	}
+#endif /* read process status */
+	return false;
 }
 
 TaskContainer::TaskContainer(Task::Ptr task, TaskBar* bar, TaskBarSettings* settingsObject, TaskBarSettings* globalSettingsObject, TQWidget *parent, const char *name)
@@ -192,9 +204,11 @@ void TaskContainer::init()
 
     if (!netwm_atoms_created) create_atoms(TQPaintDevice::x11AppDisplay());
 
+    int iconSize = READ_MERGED_TASKBAR_SETTING(iconSize);
+
     setWFlags(TQt::WNoAutoErase);
     setBackgroundMode(NoBackground);
-    animBg = TQPixmap(16, 16);
+    animBg = TQPixmap(iconSize, iconSize);
 
     installEventFilter(KickerTip::the());
 
@@ -242,7 +256,7 @@ void TaskContainer::taskChanged(bool geometryOnlyChange)
         return;
     }
 
-    const TQObject* source = TQT_TQOBJECT_CONST(sender());
+    const TQObject* source = sender();
     Task::Ptr task = 0;
     Task::List::const_iterator itEnd = tasks.constEnd();
     for (Task::List::const_iterator it = tasks.constBegin(); it != itEnd; ++it)
@@ -265,7 +279,7 @@ void TaskContainer::taskChanged(bool geometryOnlyChange)
 
 void TaskContainer::iconChanged()
 {
-    const TQObject* source = TQT_TQOBJECT_CONST(sender());
+    const TQObject* source = sender();
     Task::Ptr task = 0;
     Task::List::const_iterator itEnd = tasks.constEnd();
     for (Task::List::const_iterator it = tasks.constBegin(); it != itEnd; ++it)
@@ -366,11 +380,11 @@ void TaskContainer::checkAttention(const Task::Ptr t)
 void TaskContainer::attentionTimerFired()
 {
     assert( attentionState != -1 );
-    if (attentionState < READ_MERGED_TASBKAR_SETTING(attentionBlinkIterations)*2)
+    if (attentionState < READ_MERGED_TASKBAR_SETTING(attentionBlinkIterations)*2)
     {
         ++attentionState;
     }
-    else if (READ_MERGED_TASBKAR_SETTING(attentionBlinkIterations) < 1000)
+    else if (READ_MERGED_TASKBAR_SETTING(attentionBlinkIterations) < 1000)
     {
         attentionTimer.stop();
     }
@@ -390,9 +404,22 @@ TQSizePolicy TaskContainer::sizePolicy() const
 
 void TaskContainer::resizeEvent( TQResizeEvent * )
 {
-    // calculate the icon rect
-    TQRect br( style().subRect( TQStyle::SR_PushButtonContents, this ) );
-    iconRect = TQStyle::visualRect( TQRect(br.x() + 2, (height() - 16) / 2, 16, 16), this );
+    recalculateIconRect();
+}
+
+void TaskContainer::recalculateIconRect()
+{
+    iconSize = READ_MERGED_TASKBAR_SETTING(iconSize);
+
+    if(taskBar->showText())
+    {
+        TQRect br( style().subRect( TQStyle::SR_PushButtonContents, this ) );
+        iconRect = TQStyle::visualRect( TQRect(br.x() + 2, (height() - iconSize) / 2, iconSize, iconSize), this );
+    }
+    else
+    {
+        iconRect = TQStyle::visualRect( TQRect((width() - iconSize) / 2, (height() - iconSize) / 2, iconSize, iconSize), this );
+    }
 }
 
 void TaskContainer::add(Task::Ptr task)
@@ -581,13 +608,14 @@ void TaskContainer::drawButton(TQPainter *p)
     TQPixmap *pm((TQPixmap*)p->device());
     TQPixmap pixmap; // icon
     Task::Ptr task = 0;
-    bool iconified = !READ_MERGED_TASBKAR_SETTING(showOnlyIconified);
-    bool halo = READ_MERGED_TASBKAR_SETTING(haloText);
-    bool alwaysDrawButtons = READ_MERGED_TASBKAR_SETTING(drawButtons);
+    bool iconified = !READ_MERGED_TASKBAR_SETTING(showOnlyIconified);
+    bool halo = READ_MERGED_TASKBAR_SETTING(haloText);
+    bool alwaysDrawButtons = READ_MERGED_TASKBAR_SETTING(drawButtons);
     bool drawButton = alwaysDrawButtons ||
                       (m_mouseOver && !halo && isEnabled() &&
-                       READ_MERGED_TASBKAR_SETTING(showButtonOnHover));
+                       READ_MERGED_TASKBAR_SETTING(showButtonOnHover));
     TQFont font(TDEGlobalSettings::taskbarFont());
+    recalculateIconRect();
 
     // draw sunken if we contain the active task
     bool active = false;
@@ -608,7 +636,7 @@ void TaskContainer::drawButton(TQPainter *p)
 
         if (task->demandsAttention())
         {
-            demandsAttention = attentionState == READ_MERGED_TASBKAR_SETTING(attentionBlinkIterations) ||
+            demandsAttention = attentionState == READ_MERGED_TASKBAR_SETTING(attentionBlinkIterations) ||
                                attentionState % 2 == 0;
         }
     }
@@ -616,15 +644,15 @@ void TaskContainer::drawButton(TQPainter *p)
     font.setBold(active);
 
     TQColorGroup colors = palette().active();
-    
-    if (READ_MERGED_TASBKAR_SETTING(useCustomColors))
+
+    if (READ_MERGED_TASKBAR_SETTING(useCustomColors))
     {
-        colors.setColor( TQColorGroup::Button, READ_MERGED_TASBKAR_SETTING(taskBackgroundColor));
-        colors.setColor( TQColorGroup::Background, READ_MERGED_TASBKAR_SETTING(taskBackgroundColor) );
-        colors.setColor( TQColorGroup::ButtonText, READ_MERGED_TASBKAR_SETTING(inactiveTaskTextColor) );
-        colors.setColor( TQColorGroup::Text, READ_MERGED_TASBKAR_SETTING(inactiveTaskTextColor) );
+        colors.setColor( TQColorGroup::Button, READ_MERGED_TASKBAR_SETTING(taskBackgroundColor));
+        colors.setColor( TQColorGroup::Background, READ_MERGED_TASKBAR_SETTING(taskBackgroundColor) );
+        colors.setColor( TQColorGroup::ButtonText, READ_MERGED_TASKBAR_SETTING(inactiveTaskTextColor) );
+        colors.setColor( TQColorGroup::Text, READ_MERGED_TASKBAR_SETTING(inactiveTaskTextColor) );
     }
-    
+
     if (demandsAttention)
     {
         if (!drawButton)
@@ -659,7 +687,7 @@ void TaskContainer::drawButton(TQPainter *p)
     // get the task icon
     if (task)
     {
-        pixmap = task->pixmap();
+        pixmap = task->icon(iconSize, iconSize, true);
     }
 
     bool sunken = isDown() || (alwaysDrawButtons && (active || aboutToActivate));
@@ -671,7 +699,7 @@ void TaskContainer::drawButton(TQPainter *p)
     // draw button background
     if (drawButton)
     {
-        if (READ_MERGED_TASBKAR_SETTING(drawButtons) && KickerSettings::showDeepButtons()) {
+        if (READ_MERGED_TASKBAR_SETTING(drawButtons) && KickerSettings::showDeepButtons()) {
             style().tqdrawPrimitive(TQStyle::PE_ButtonBevel, p,
                               TQRect(1, 1, width()-3, height()-2),
                               colors, sunken ? TQStyle::Style_On : TQStyle::Style_Raised);
@@ -690,21 +718,21 @@ void TaskContainer::drawButton(TQPainter *p)
     }
 
     TQString text = name();  // find text
-    int textPos = ( taskBar->showIcons() && (!pixmap.isNull() || m_startup)) ? 2 + 16 + 2 : 0;
+    int textPos = ( taskBar->showIcons() && (!pixmap.isNull() || m_startup)) ? 2 + iconSize + 2 : 0;
 
     // show icons
     if (taskBar->showIcons())
     {
       if (pixmap.isNull() && m_startup)
-          pixmap = SmallIcon(m_startup->icon());
+          pixmap = kapp->iconLoader()->loadIcon(m_startup->icon(), TDEIcon::Panel, iconSize);
 
       if ( !pixmap.isNull() )
       {
-          // make sure it is no larger than 16x16
-          if ( pixmap.width() > 16 || pixmap.height() > 16 )
+          // make sure it is no larger than icon size
+          if ( pixmap.width() > iconSize || pixmap.height() > iconSize )
           {
               TQImage tmp = pixmap.convertToImage();
-              pixmap.convertFromImage( tmp.smoothScale( 16, 16 ) );
+              pixmap.convertFromImage( tmp.smoothScale( iconSize, iconSize ) );
           }
 
           // fade out the icon when minimized
@@ -718,28 +746,36 @@ void TaskContainer::drawButton(TQPainter *p)
       }
 
       // modified overlay icon
-      if (taskBar->showText())
+      static TQString modStr = "[" + i18n( "modified" ) + "]";
+      int modStrPos = text.find( modStr );
+      if (modStrPos >= 0)
       {
-        static TQString modStr = "[" + i18n( "modified" ) + "]";
-        int modStrPos = text.find( modStr );
-        if (modStrPos >= 0)
+        TQRect r;
+        TQPixmap modPixmap = SmallIcon("modified");
+        if (iconified)
         {
-          // +1 because we include a space after the closing brace.
-          text.remove(modStrPos, modStr.length() + 1);
-          TQPixmap modPixmap = SmallIcon("modified");
-
-          // draw modified overlay
-          if (!modPixmap.isNull())
-          {
-            TQRect r = TQStyle::visualRect(TQRect(br.x() + textPos,(height() - 16) / 2, 16, 16), this);
-            if (iconified)
-            {
-              TDEIconEffect::semiTransparent(modPixmap);
-            }
-            p->drawPixmap(r, modPixmap);
-            textPos += 16 + 2;
-          }
+            TDEIconEffect::semiTransparent(modPixmap);
         }
+
+        if (taskBar->showText()) // has text
+        {
+            // +1 because we include a space after the closing brace.
+            text.remove(modStrPos, modStr.length() + 1);
+
+            // draw modified overlay
+            if (!modPixmap.isNull())
+            {
+                r = TQStyle::visualRect(TQRect(br.x() + textPos,(height() - iconSize) / 2, iconSize, iconSize), this);
+                textPos += iconSize + 2;
+            }
+         }
+         else if (taskBar->showIcons()) // has only icon
+         {
+             r = TQRect(0, 0, iconSize / 2, iconSize / 2);
+             r.moveBottomRight(iconRect.bottomRight());
+         }
+
+         p->drawPixmap(r, modPixmap);
       }
     }
 
@@ -765,9 +801,9 @@ void TaskContainer::drawButton(TQPainter *p)
           }
           else // hack for the dotNET style and others
           {
-              if (READ_MERGED_TASBKAR_SETTING(useCustomColors))
+              if (READ_MERGED_TASKBAR_SETTING(useCustomColors))
               {
-                  textPen = TQPen(READ_MERGED_TASBKAR_SETTING(activeTaskTextColor));
+                  textPen = TQPen(READ_MERGED_TASKBAR_SETTING(activeTaskTextColor));
               }
               else
               {
@@ -775,7 +811,7 @@ void TaskContainer::drawButton(TQPainter *p)
               }
           }
 
-          int availableWidth = width() - (br.x() * 2) - textPos - 2 - (READ_MERGED_TASBKAR_SETTING(drawButtons) && KickerSettings::showDeepButtons())?2:0;
+          int availableWidth = width() - (br.x() * 2) - textPos - 2 - (READ_MERGED_TASKBAR_SETTING(drawButtons) && KickerSettings::showDeepButtons())?2:0;
           if (m_filteredTasks.count() > 1)
           {
               availableWidth -= 8;
@@ -852,7 +888,7 @@ void TaskContainer::drawButton(TQPainter *p)
     }
 
     // draw popup arrow
-    if ((m_filteredTasks.count() > 1) && (!(READ_MERGED_TASBKAR_SETTING(drawButtons) && KickerSettings::showDeepButtons())))
+    if ((m_filteredTasks.count() > 1) && (!(READ_MERGED_TASKBAR_SETTING(drawButtons) && KickerSettings::showDeepButtons())))
     {
         TQStyle::PrimitiveElement e = TQStyle::PE_ArrowLeft;
 
@@ -995,14 +1031,14 @@ void TaskContainer::mousePressEvent( TQMouseEvent* e )
     switch (e->button())
     {
         case Qt::LeftButton:
-            buttonAction = READ_MERGED_TASBKAR_ACTION(m_settingsObject->LeftButton);
+            buttonAction = READ_MERGED_TASKBAR_ACTION(m_settingsObject->LeftButton);
             break;
         case Qt::MidButton:
-            buttonAction = READ_MERGED_TASBKAR_ACTION(m_settingsObject->MiddleButton);
+            buttonAction = READ_MERGED_TASKBAR_ACTION(m_settingsObject->MiddleButton);
             break;
         case Qt::RightButton:
         default:
-            buttonAction = READ_MERGED_TASBKAR_ACTION(m_settingsObject->RightButton);
+            buttonAction = READ_MERGED_TASKBAR_ACTION(m_settingsObject->RightButton);
             break;
     }
 
@@ -1018,14 +1054,14 @@ void TaskContainer::mouseReleaseEvent(TQMouseEvent *e)
 {
     m_dragStartPos = TQPoint();
 
-    if (!READ_MERGED_TASBKAR_SETTING(drawButtons))
+    if (!READ_MERGED_TASKBAR_SETTING(drawButtons))
     {
         setDown(false);
     }
 
     // This is to avoid the flicker caused by redrawing the
     // button as unpressed just before it's activated.
-    if (!TQT_TQRECT_OBJECT(rect()).contains(e->pos()))
+    if (!rect().contains(e->pos()))
     {
         TQToolButton::mouseReleaseEvent(e);
         return;
@@ -1036,14 +1072,14 @@ void TaskContainer::mouseReleaseEvent(TQMouseEvent *e)
     switch (e->button())
     {
         case Qt::LeftButton:
-            buttonAction = READ_MERGED_TASBKAR_ACTION(m_settingsObject->LeftButton);
+            buttonAction = READ_MERGED_TASKBAR_ACTION(m_settingsObject->LeftButton);
             break;
         case Qt::MidButton:
-            buttonAction = READ_MERGED_TASBKAR_ACTION(m_settingsObject->MiddleButton);
+            buttonAction = READ_MERGED_TASKBAR_ACTION(m_settingsObject->MiddleButton);
             break;
         case Qt::RightButton:
         default:
-            buttonAction = READ_MERGED_TASBKAR_ACTION(m_settingsObject->RightButton);
+            buttonAction = READ_MERGED_TASKBAR_ACTION(m_settingsObject->RightButton);
             break;
     }
 
@@ -1223,7 +1259,7 @@ void TaskContainer::popupMenu(int action)
             return;
         }
 
-        m_menu = new TaskRMBMenu(m_filteredTasks, taskBar->showAllWindows(), (READ_MERGED_TASBKAR_SETTING(allowDragAndDropReArrange))?makeTaskMoveMenu():NULL);
+        m_menu = new TaskRMBMenu(m_filteredTasks, taskBar->showAllWindows(), (READ_MERGED_TASKBAR_SETTING(allowDragAndDropReArrange))?makeTaskMoveMenu():NULL);
     }
     else
     {
@@ -1328,11 +1364,6 @@ void TaskContainer::mouseMoveEvent( TQMouseEvent* e )
 
 bool TaskContainer::startDrag(const TQPoint& pos)
 {
-    if (m_filteredTasks.count() != 1)
-    {
-        return false;
-    }
-
     int delay = TDEGlobalSettings::dndEventDelay();
 
     if ((m_dragStartPos - pos).manhattanLength() > delay)
@@ -1452,7 +1483,7 @@ void TaskContainer::dragEnterEvent( TQDragEnterEvent* e )
         return;
     }
 
-    if (e->source() && (e->source()->parent() == this->parent()) && TaskDrag::canDecode(e) && READ_MERGED_TASBKAR_SETTING(allowDragAndDropReArrange) && (!READ_MERGED_TASBKAR_SETTING(sortByApp)))
+    if (e->source() && (e->source()->parent() == this->parent()) && TaskDrag::canDecode(e) && READ_MERGED_TASKBAR_SETTING(allowDragAndDropReArrange) && (!READ_MERGED_TASKBAR_SETTING(sortByApp)))
     {
         e->accept();
     }
@@ -1480,7 +1511,7 @@ void TaskContainer::dropEvent( TQDropEvent* e )
         return;
     }
 
-    if ((e->source()->parent() == this->parent()) && TaskDrag::canDecode(e) && READ_MERGED_TASBKAR_SETTING(allowDragAndDropReArrange) && (!READ_MERGED_TASBKAR_SETTING(sortByApp)))
+    if ((e->source()->parent() == this->parent()) && TaskDrag::canDecode(e) && READ_MERGED_TASKBAR_SETTING(allowDragAndDropReArrange) && (!READ_MERGED_TASKBAR_SETTING(sortByApp)))
     {
         if (taskBar->taskMoveHandler(TaskMoveDestination::Position, TaskDrag::decode(e), TQWidget::mapTo(taskBar, e->pos()))) {
             e->accept();
@@ -1631,7 +1662,7 @@ void TaskContainer::updateFilteredTaskList()
     {
         Task::Ptr t = *it;
         if ((taskBar->showAllWindows() || t->isOnCurrentDesktop()) &&
-            (!READ_MERGED_TASBKAR_SETTING(showOnlyIconified) || t->isIconified()))
+            (!READ_MERGED_TASKBAR_SETTING(showOnlyIconified) || t->isIconified()))
         {
             pid_t pid = 0;
 #ifdef Q_WS_X11
@@ -1652,15 +1683,15 @@ void TaskContainer::updateFilteredTaskList()
             if (pid < 0) {
                 m_filteredTasks.append(t);
             }
-            else if (READ_MERGED_TASBKAR_SETTING(showTaskStates) != m_settingsObject->ShowAll) {
+            else if (READ_MERGED_TASKBAR_SETTING(showTaskStates) != m_settingsObject->ShowAll) {
                 if (is_process_resumable(pid)) {
-                    if (READ_MERGED_TASBKAR_SETTING(showTaskStates) == m_settingsObject->ShowAll) {
+                    if (READ_MERGED_TASKBAR_SETTING(showTaskStates) == m_settingsObject->ShowAll) {
                         m_filteredTasks.append(t);
                     }
-                    else if (READ_MERGED_TASBKAR_SETTING(showTaskStates) == m_settingsObject->ShowStopped) {
+                    else if (READ_MERGED_TASKBAR_SETTING(showTaskStates) == m_settingsObject->ShowStopped) {
                         m_filteredTasks.append(t);
                     }
-                    else if (READ_MERGED_TASBKAR_SETTING(showTaskStates) == m_settingsObject->ShowRunning) {
+                    else if (READ_MERGED_TASKBAR_SETTING(showTaskStates) == m_settingsObject->ShowRunning) {
                         t->publishIconGeometry( TQRect());
                     }
                     else {
@@ -1668,13 +1699,13 @@ void TaskContainer::updateFilteredTaskList()
                     }
                 }
                 else {
-                    if (READ_MERGED_TASBKAR_SETTING(showTaskStates) == m_settingsObject->ShowAll) {
+                    if (READ_MERGED_TASKBAR_SETTING(showTaskStates) == m_settingsObject->ShowAll) {
                         m_filteredTasks.append(t);
                     }
-                    else if (READ_MERGED_TASBKAR_SETTING(showTaskStates) == m_settingsObject->ShowStopped) {
+                    else if (READ_MERGED_TASKBAR_SETTING(showTaskStates) == m_settingsObject->ShowStopped) {
                         t->publishIconGeometry( TQRect());
                     }
-                    else if (READ_MERGED_TASBKAR_SETTING(showTaskStates) == m_settingsObject->ShowRunning) {
+                    else if (READ_MERGED_TASKBAR_SETTING(showTaskStates) == m_settingsObject->ShowRunning) {
                         m_filteredTasks.append(t);
                     }
                     else {
@@ -1695,7 +1726,7 @@ void TaskContainer::updateFilteredTaskList()
     // sort container list by desktop
     if (taskBar->sortByDesktop() && m_filteredTasks.count() > 1)
     {
-        TQValueVector<QPair<int, Task::Ptr> > sorted;
+        TQValueVector<TQPair<int, Task::Ptr> > sorted;
         sorted.resize(m_filteredTasks.count());
         int i = 0;
 
@@ -1710,7 +1741,7 @@ void TaskContainer::updateFilteredTaskList()
         qHeapSort(sorted);
 
         m_filteredTasks.clear();
-        for (TQValueVector<QPair<int, Task::Ptr> >::iterator it = sorted.begin();
+        for (TQValueVector<TQPair<int, Task::Ptr> >::iterator it = sorted.begin();
              it != sorted.end();
              ++it)
         {
@@ -1742,6 +1773,8 @@ void TaskContainer::settingsChanged()
 
 void TaskContainer::updateKickerTip(KickerTip::Data& data)
 {
+    int iconSize = READ_MERGED_TASKBAR_SETTING(iconSize);
+
     if (m_startup)
     {
         data.message = m_startup->text();
@@ -1749,7 +1782,7 @@ void TaskContainer::updateKickerTip(KickerTip::Data& data)
         data.subtext = i18n("Loading application ...");
         data.icon = TDEGlobal::iconLoader()->loadIcon(m_startup->icon(),
                                                     TDEIcon::Small,
-                                                    TDEIcon::SizeMedium,
+						    iconSize,
                                                     TDEIcon::DefaultState,
                                                     0, true);
         return;
@@ -1761,21 +1794,18 @@ void TaskContainer::updateKickerTip(KickerTip::Data& data)
     
     if (m_filteredTasks.count() > 0)
     {
-        if (READ_MERGED_TASBKAR_SETTING(showThumbnails) &&
+        if (READ_MERGED_TASKBAR_SETTING(showThumbnails) &&
             m_filteredTasks.count() == 1)
         {
             Task::Ptr t = m_filteredTasks.first();
     
-            pixmap = t->thumbnail(READ_MERGED_TASBKAR_SETTING(thumbnailMaxDimension));
+            pixmap = t->thumbnail(READ_MERGED_TASKBAR_SETTING(thumbnailMaxDimension));
         }
     
         if (pixmap.isNull() && tasks.count())
         {
             // try to load icon via net_wm
-            pixmap = KWin::icon(tasks.last()->window(),
-                                TDEIcon::SizeMedium,
-                                TDEIcon::SizeMedium,
-                                true);
+            pixmap = KWin::icon(tasks.last()->window(), iconSize, iconSize, true);
         }
     
         // Collect all desktops the tasks are on. Sort naturally.
@@ -1809,7 +1839,7 @@ void TaskContainer::updateKickerTip(KickerTip::Data& data)
             }
         }
     
-        if (READ_MERGED_TASBKAR_SETTING(showAllWindows) && KWin::numberOfDesktops() > 1)
+        if (READ_MERGED_TASKBAR_SETTING(showAllWindows) && KWin::numberOfDesktops() > 1)
         {
             if (desktopMap.isEmpty())
             {
