@@ -25,7 +25,7 @@ class DwString;
 
 class MimeLibTester : public KUnitTest::SlotTester
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public slots:
