@@ -452,7 +452,7 @@ int KMixApplet::heightForWidth(int) const {
 
 TQSizePolicy KMixApplet::sizePolicy() const {
     //    return TQSizePolicy(TQSizePolicy::Preferred,TQSizePolicy::Preferred);
-    if ( orientation() == Qt::Vertical ) {
+    if ( orientation() == TQt::Vertical ) {
 	//kdDebug(67100) << "KMixApplet::sizePolicy=(Ignored,Fixed)\n";
         return TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);
     }
