@@ -38,7 +38,7 @@ class ViewDockAreaPopup;
 class Volume;
 
 class KMixDockWidget : public KSystemTray  {
-   Q_OBJECT
+   TQ_OBJECT
   
    friend class KMixWindow;
 
