@@ -75,7 +75,7 @@
 /** KNetworkConf is the base class of the project */
 class KNetworkConf : public KNetworkConfDlg, public DCOPObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     /** construtor */
@@ -175,8 +175,6 @@ class KNetworkConf : public KNetworkConfDlg, public DCOPObject
 			TQString broadcast);
     /** Returns a list of strings of all the configured devices. */
     TQStringList getDeviceList();
-    /** Sets the TQPushButton::autoResize() in true for all buttons. */
-    void makeButtonsResizeable();
 
     /** Adds a new host to the TDEListView that has the known hosts. */
     void addKnownHostSlot();
