@@ -437,7 +437,7 @@ void KNComposer::slotUndo()
 
     if (fw->inherits("KEdit"))
         ((TQMultiLineEdit*)fw)->undo();
-    else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+    else if (fw->inherits("TQLineEdit"))
         ((TQLineEdit*)fw)->undo();
 }
 
@@ -448,7 +448,7 @@ void KNComposer::slotRedo()
 
     if (fw->inherits("KEdit"))
         ((TQMultiLineEdit*)fw)->redo();
-    else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+    else if (fw->inherits("TQLineEdit"))
         ((TQLineEdit*)fw)->redo();
 }
 
@@ -459,7 +459,7 @@ void KNComposer::slotCut()
 
   if (fw->inherits("KEdit"))
     ((TQMultiLineEdit*)fw)->cut();
-  else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+  else if (fw->inherits("TQLineEdit"))
     ((TQLineEdit*)fw)->cut();
   else kdDebug(5003) << "wrong focus widget" << endl;
 }
@@ -471,7 +471,7 @@ void KNComposer::slotCopy()
 
   if (fw->inherits("KEdit"))
     ((TQMultiLineEdit*)fw)->copy();
-  else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+  else if (fw->inherits("TQLineEdit"))
     ((TQLineEdit*)fw)->copy();
   else kdDebug(5003) << "wrong focus widget" << endl;
 
@@ -485,7 +485,7 @@ void KNComposer::slotPaste()
 
   if (fw->inherits("KEdit"))
     ((TQMultiLineEdit*)fw)->paste();
-  else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+  else if (fw->inherits("TQLineEdit"))
     ((TQLineEdit*)fw)->paste();
   else kdDebug(5003) << "wrong focus widget" << endl;
 }
@@ -495,9 +495,9 @@ void KNComposer::slotSelectAll()
   TQWidget* fw = focusWidget();
   if (!fw) return;
 
-  if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+  if (fw->inherits("TQLineEdit"))
       ((TQLineEdit*)fw)->selectAll();
-  else if (fw->inherits(TQMULTILINEEDIT_OBJECT_NAME_STRING))
+  else if (fw->inherits("TQMultiLineEdit"))
     ((TQMultiLineEdit*)fw)->selectAll();
 }
 
@@ -2011,7 +2011,7 @@ KNComposer::Editor::~Editor()
 //-----------------------------------------------------------------------------
 bool KNComposer::Editor::eventFilter(TQObject*o, TQEvent* e)
 {
-  if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this))
+  if (o == this)
     KCursor::autoHideEventFilter(o, e);
 
   if (e->type() == TQEvent::KeyPress)
