@@ -27,7 +27,7 @@
 #include <tqstring.h>
 #include <tqstringlist.h>
 
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace KODE {
 
