@@ -225,13 +225,13 @@ bool QDesignerToolBar::eventFilter( TQObject *o, TQEvent *e )
     if ( !o || !e || o->inherits( "TQDockWindowHandle" ) || o->inherits( "TQDockWindowTitleBar" ) )
 	return TQToolBar::eventFilter( o, e );
 
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) && e->type() == TQEvent::MouseButtonPress &&
+    if ( o == this && e->type() == TQEvent::MouseButtonPress &&
 	 ( ( TQMouseEvent*)e )->button() == Qt::LeftButton ) {
 	mousePressEvent( (TQMouseEvent*)e );
 	return true;
     }
 
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) )
+    if ( o == this )
 	return TQToolBar::eventFilter( o, e );
 
     if ( e->type() == TQEvent::MouseButtonPress ) {
@@ -452,7 +452,7 @@ void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
 
     TQString type = a->inherits( "TQActionGroup" ) ? TQString( "application/x-designer-actiongroup" ) :
 	a->inherits( "QSeparatorAction" ) ? TQString( "application/x-designer-separator" ) : TQString( "application/x-designer-actions" );
-    TQStoredDrag *drag = new TQStoredDrag( type, this );
+    TQStoredDrag *drag = new TQStoredDrag( type.utf8(), this );
     TQString s = TQString::number( (long)a ); // #### huha, that is evil
     drag->setEncodedData( TQCString( s.latin1() ) );
     drag->setPixmap( a->iconSet().pixmap() );
@@ -1076,7 +1076,7 @@ void QDesignerPopupMenu::mouseMoveEvent( TQMouseEvent *e )
 
     TQString type = a->inherits( "TQActionGroup" ) ? TQString( "application/x-designer-actiongroup" ) :
 	a->inherits( "QSeparatorAction" ) ? TQString( "application/x-designer-separator" ) : TQString( "application/x-designer-actions" );
-    TQStoredDrag *drag = new TQStoredDrag( type, this );
+    TQStoredDrag *drag = new TQStoredDrag( type.utf8(), this );
     TQString s = TQString::number( (long)a ); // #### huha, that is evil
     drag->setEncodedData( TQCString( s.latin1() ) );
     drag->setPixmap( a->iconSet().pixmap() );
