@@ -705,25 +705,25 @@ bool MainWindow::eventFilter(TQObject *o, TQEvent *e)
     case TQEvent::Close:
       break;
     case TQEvent::DragEnter:
-      if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(qWorkspace()) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(workspace()) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(workspace()->viewport())) {
+      if (o == qWorkspace() || o == workspace() || o == workspace()->viewport()) {
         workspace()->contentsDragEnterEvent((TQDragEnterEvent*)e);
         return true;
       }
       break;
     case TQEvent::DragMove:
-      if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(qWorkspace()) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(workspace()) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(workspace()->viewport())) {
+      if (o == qWorkspace() || o == workspace() || o == workspace()->viewport()) {
         workspace()->contentsDragMoveEvent((TQDragMoveEvent*)e);
         return true;
       }
       break;
     case TQEvent::Drop:
-      if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(qWorkspace()) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(workspace()) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(workspace()->viewport())) {
+      if (o == qWorkspace() || o == workspace() || o == workspace()->viewport()) {
         workspace()->contentsDropEvent((TQDropEvent*)e);
         return true;
       }
       break;
     case TQEvent::Show:
-      if (TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(this))
+      if (o != this)
         break;
       if (((TQShowEvent*)e)->spontaneous())
         break;
