@@ -188,7 +188,7 @@ int QDesignerTabWidget::count() const
 
 bool QDesignerTabWidget::eventFilter( TQObject *o, TQEvent *e )
 {
-    if ( TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(tabBar()) ) return false;
+    if ( o != tabBar() ) return false;
 
     switch ( e->type() ) {
     case TQEvent::MouseButtonPress: {
@@ -468,7 +468,7 @@ int EditorTabWidget::count() const
 
 bool EditorTabWidget::eventFilter( TQObject *o, TQEvent *e )
 {
-    if ( TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(tabBar()) ) return false;
+    if ( o != tabBar() ) return false;
 
     switch ( e->type() ) {
     case TQEvent::MouseButtonPress: {
@@ -1904,17 +1904,10 @@ void TQLayoutWidget::updateSizePolicy()
 		    vt |= TQSizePolicy::Maximum;
 	    }
 	}
-#ifdef USE_QT4
 	if ( layout()->expanding() & TQSizePolicy::Horizontally )
 	    ht = TQSizePolicy::Expanding;
 	if ( layout()->expanding() & TQSizePolicy::Vertically )
 	    vt = TQSizePolicy::Expanding;
-#else // USE_QT4
-	if ( layout()->expanding() & TQSizePolicy::Horizontally )
-	    ht = TQSizePolicy::Expanding;
-	if ( layout()->expanding() & TQSizePolicy::Vertically )
-	    vt = TQSizePolicy::Expanding;
-#endif // USE_QT4
 
 	layout()->invalidate();
     }
