@@ -715,11 +715,11 @@ static ParseNode f_inputText(Parser*, const ParameterList& params)
 
 static ParseNode f_inputPassword(Parser*, const ParameterList& params)
 {
-  TQCString value;
+  TQString value;
   if (params.count() > 1)
-    value = params[1].toString().local8Bit();
+    value = params[1].toString();
   KPasswordDialog::getPassword(value, params[0].toString());
-  return TQString(TQString::fromLocal8Bit(value));
+  return value;
 }
 
 static ParseNode f_inputValue(Parser*, const ParameterList& params)
