@@ -295,7 +295,7 @@ TQString KommanderWidget::DCOPQuery(const TQStringList& a_query)
       byteDataStream << a_query[i+3].toDouble();
     else if (argTypes[i] == "bool")
       byteDataStream << (bool)(a_query[i+3] != "false" && a_query[i+3] != "false" && a_query[i+3] != "0");
-    else if (argTypes[i] == TQSTRINGLIST_OBJECT_NAME_STRING)
+    else if (argTypes[i] == "TQStringList")
       if (a_query[i+3].find('\n') != -1)
         byteDataStream << TQStringList::split("\n", a_query[i+3], true);
       else
@@ -312,7 +312,7 @@ TQString KommanderWidget::DCOPQuery(const TQStringList& a_query)
   }
 
   TQDataStream byteReplyStream(byteReply, IO_ReadOnly);
-  if (replyType == TQSTRING_OBJECT_NAME_STRING)
+  if (replyType == "TQString")
   {
     TQString text;
     byteReplyStream >> text;
@@ -330,7 +330,7 @@ TQString KommanderWidget::DCOPQuery(const TQStringList& a_query)
     byteReplyStream >> b;
     return TQString::number(b);
   }
-  else if (replyType == TQSTRINGLIST_OBJECT_NAME_STRING)
+  else if (replyType == "TQStringList")
   {
     TQStringList text;
     byteReplyStream >> text;
@@ -413,12 +413,12 @@ void KommanderWidget::printError(const TQString& a_error) const
       case KDialogBase::Yes:
         break;
       case KDialogBase::Cancel:
-        if (parentDialog()->inherits(TQDIALOG_OBJECT_NAME_STRING))
+        if (parentDialog()->inherits("TQDialog"))
         {
           parentDialog()->close();
           exit(-1);
         }
-        else if (parentDialog()->inherits(TQMAINWINDOW_OBJECT_NAME_STRING))
+        else if (parentDialog()->inherits("TQMainWindow"))
           kapp->quit();
     }
   }
@@ -655,7 +655,7 @@ TQWidget* KommanderWidget::parentDialog() const
   while (superParent->parent())
   {
     superParent = superParent->parent();
-    if (superParent->inherits(TQDIALOG_OBJECT_NAME_STRING) || superParent->inherits(TQMAINWINDOW_OBJECT_NAME_STRING))
+    if (superParent->inherits("TQDialog") || superParent->inherits("TQMainWindow"))
       break;
   }
   return (TQWidget*)superParent;
@@ -695,7 +695,7 @@ TQString KommanderWidget::handleDCOP(const int function, const TQStringList& arg
     case DCOP::children:
     {
       TQStringList matching;
-      TQObjectList* widgets = current->queryList(TQWIDGET_OBJECT_NAME_STRING, 0, false, args.count() == 0 || args[0] != "false");
+      TQObjectList* widgets = current->queryList("TQWidget", 0, false, args.count() == 0 || args[0] != "false");
       for (TQObject* w = widgets->first(); w; w = widgets->next())
         if (w->name() && (dynamic_cast<KommanderWidget*>(w)))
             matching.append(w->name());
