@@ -21,7 +21,7 @@
 
 class KDE_EXPORT ToolBox : public TQToolBox, public KommanderWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   TQ_PROPERTY(TQString populationText READ populationText WRITE setPopulationText DESIGNABLE false)
   TQ_PROPERTY(TQStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
