@@ -100,6 +100,7 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, TQWidget *
    ,m_bAscending(true)
    ,m_itemFound(false)
    ,m_restored(false)
+   ,m_sortOrder(0)
    ,m_filenameColumn(0)
    ,m_itemToGoTo("")
    ,m_backgroundTimer(0)
@@ -173,8 +174,8 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, TQWidget *
    connect( header(), TQT_SIGNAL(sizeChange( int, int, int )), TQT_SLOT(slotUpdateBackground()) );
 
    viewport()->setMouseTracking( true );
-   viewport()->setFocusPolicy( TQ_WheelFocus );
-   setFocusPolicy( TQ_WheelFocus );
+   viewport()->setFocusPolicy( TQWidget::WheelFocus );
+   setFocusPolicy( TQWidget::WheelFocus );
    setAcceptDrops( true );
 
    //looks better with the statusbar
@@ -236,9 +237,9 @@ void KonqBaseListViewWidget::readProtocolConfig( const KURL & url )
          lstColumns << column;
       const TQString type = (*extraFieldsIt).type; // ## TODO use when sorting
       TQVariant::Type t = TQVariant::Invalid;
-      if ( type.lower() == TQString(TQSTRING_OBJECT_NAME_STRING).lower() )
+      if ( type.lower() == TQString("TQString").lower() )
           t = TQVariant::String;
-      else if ( type.lower() == TQString(TQDATETIME_OBJECT_NAME_STRING).lower() )
+      else if ( type.lower() == TQString("TQDateTime").lower() )
           t = TQVariant::DateTime;
       else
           kdWarning() << "Unsupported ExtraType '" << type << "'" << endl;
@@ -522,6 +523,41 @@ void KonqBaseListViewWidget::contentsWheelEvent( TQWheelEvent *e )
    TDEListView::contentsWheelEvent( e );
 }
 
+void KonqBaseListViewWidget::contentsMouseDoubleClickEvent(TQMouseEvent *e)
+{
+  if (m_rubber)
+  {
+    TQRect r(m_rubber->normalize());
+    delete m_rubber;
+    m_rubber = NULL;
+    repaintContents(r, false);
+  }
+
+  TQPoint vp = contentsToViewport(e->pos());
+  KonqBaseListViewItem* item = isExecuteArea(vp) ?
+    static_cast<KonqBaseListViewItem*>(itemAt(vp)) : NULL;
+
+  if (item)
+  {
+    TDEListView::contentsMouseDoubleClickEvent(e);
+  }
+  else if (m_pSettings->doubleClickMoveToParent())
+  {
+    KParts::URLArgs args;
+    args.trustedSource = true;
+    KURL baseURL(m_dirLister->url().internalReferenceURL());
+    if (baseURL.isEmpty())
+    {
+      baseURL = m_dirLister->url();
+    }
+    KURL upURL = baseURL.upURL();
+    if (!upURL.isEmpty())
+    {
+      m_pBrowserView->extension()->openURLRequest(upURL, args);
+    }
+  }
+}
+
 void KonqBaseListViewWidget::leaveEvent( TQEvent *e )
 {
    if ( m_activeItem != 0 )
@@ -1180,11 +1216,7 @@ bool KonqBaseListViewWidget::openURL( const KURL &url )
    {
       m_pBrowserView->newIconSize( m_pBrowserView->m_pProps->iconSize() );
       m_pBrowserView->m_paShowDot->setChecked( m_pBrowserView->m_pProps->isShowingDotFiles() );
-      if ( m_pBrowserView->m_paCaseInsensitive->isChecked() != m_pBrowserView->m_pProps->isCaseInsensitiveSort() ) {
-          m_pBrowserView->m_paCaseInsensitive->setChecked( m_pBrowserView->m_pProps->isCaseInsensitiveSort() );
-          // This is in case openURL returned all items synchronously.
-          sort();
-      }
+      m_sortOrder = m_pBrowserView->m_pProps->getSortOrder();
 
       // It has to be "viewport()" - this is what KonqDirPart's slots act upon,
       // and otherwise we get a color/pixmap in the square between the scrollbars.
@@ -1458,7 +1490,7 @@ KonqBaseListViewWidget::iterator KonqBaseListViewWidget::iterator::operator++(in
 
 void KonqBaseListViewWidget::paintEmptyArea( TQPainter *p, const TQRect &r )
 {
-   const TQPixmap *pm = TQT_TQPIXMAP_CONST(viewport()->paletteBackgroundPixmap());
+   const TQPixmap *pm = viewport()->paletteBackgroundPixmap();
 
    if (!pm || pm->isNull())
       p->fillRect(r, viewport()->backgroundColor());
@@ -1540,11 +1572,6 @@ void KonqBaseListViewWidget::slotUpdateBackground()
    }
 }
 
-bool KonqBaseListViewWidget::caseInsensitiveSort() const
-{
-    return m_pBrowserView->m_pProps->isCaseInsensitiveSort();
-}
-
 // based on isExecuteArea from tdelistview.cpp
 int KonqBaseListViewWidget::executeArea( TQListViewItem *_item )
 {
