@@ -231,7 +231,7 @@ ChatMessagePart::ChatMessagePart( Kopete::ChatSession *mgr, TQWidget *parent, co
 	// Write the template to TDEHTMLPart
 	writeTemplate();
 
-	view()->setFocusPolicy( TQ_NoFocus );
+	view()->setFocusPolicy( TQWidget::NoFocus );
 
 	d->tt=new ToolTip( this );
 
