@@ -65,7 +65,7 @@ class BlackLister;
  */
 class KOPETE_EXPORT Account : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	TQ_ENUMS( AddMode )
