@@ -91,7 +91,7 @@ KVncView::KVncView(TQWidget *parent,
 	password = _password;
 	dpy = tqt_xdisplay();
 	setFixedSize(16,16);
-	setFocusPolicy(TQ_StrongFocus);
+	setFocusPolicy(TQWidget::StrongFocus);
 
 	m_cb = TQApplication::clipboard();
 	connect(m_cb, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(selectionChanged()));
