@@ -32,7 +32,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#ifdef USE_SOLARIS
+#ifdef Q_OS_SOLARIS
 #include <strings.h>
 #endif
 
@@ -132,7 +132,7 @@ static enum rfbNewClientAction newClientHook(struct _rfbClientRec *cl)
 	return self->handleNewClient(cl);
 }
 
-static Bool passwordCheck(rfbClientPtr cl,
+static rfbBool passwordCheck(rfbClientPtr cl,
 			  const char* encryptedPassword,
 			  int len)
 {
@@ -140,7 +140,7 @@ static Bool passwordCheck(rfbClientPtr cl,
 	return self->handleCheckPassword(cl, encryptedPassword, len);
 }
 
-static void keyboardHook(Bool down, KeySym keySym, rfbClientPtr)
+static void keyboardHook(rfbBool down, rfbKeySym keySym, rfbClientPtr)
 {
 	self->handleKeyEvent(down ? true : false, keySym);
 }
@@ -155,6 +155,7 @@ static void clientGoneHook(rfbClientPtr)
 	self->handleClientGone();
 }
 
+#ifdef USE_MODIFIED_BUILTIN_LIBVNCSERVER
 static void negotiationFinishedHook(rfbClientPtr cl)
 {
 	self->handleNegotiationFinished(cl);
@@ -164,6 +165,7 @@ static void inetdDisconnectHook()
 {
 	self->handleClientGone();
 }
+#endif
 
 static void clipboardHook(char* str,int len, rfbClientPtr)
 {
@@ -457,36 +459,38 @@ void RFBController::startServer(int inetdFd, bool xtestGrab)
 	rfbLogEnable(0);
 	server = rfbGetScreen(0, 0, w, h, (bpp*8), 8, bpp);
 
+	rfbSetServerVersionIdentity(server, "krfb %s", KDE::versionString());
+
 	server->paddedWidthInBytes = framebufferImage->bytes_per_line;
 
-	server->rfbServerFormat.bitsPerPixel = framebufferImage->bits_per_pixel;
-	server->rfbServerFormat.depth = framebufferImage->depth;
-	server->rfbServerFormat.trueColour = (CARD8) TRUE;
-	server->rfbServerFormat.bigEndian =  (CARD8) ((framebufferImage->bitmap_bit_order == MSBFirst) ? TRUE : FALSE);
+	server->serverFormat.bitsPerPixel = framebufferImage->bits_per_pixel;
+	server->serverFormat.depth = framebufferImage->depth;
+	server->serverFormat.trueColour = (uint8_t) TRUE;
+	server->serverFormat.bigEndian =  (uint8_t) ((framebufferImage->bitmap_bit_order == MSBFirst) ? TRUE : FALSE);
 
-	if ( server->rfbServerFormat.bitsPerPixel == 8 ) {
-		server->rfbServerFormat.redShift = 0;
-		server->rfbServerFormat.greenShift = 3;
-		server->rfbServerFormat.blueShift = 6;
-		server->rfbServerFormat.redMax   = 7;
-		server->rfbServerFormat.greenMax = 7;
-		server->rfbServerFormat.blueMax  = 3;
+	if ( server->serverFormat.bitsPerPixel == 8 ) {
+		server->serverFormat.redShift = 0;
+		server->serverFormat.greenShift = 3;
+		server->serverFormat.blueShift = 6;
+		server->serverFormat.redMax   = 7;
+		server->serverFormat.greenMax = 7;
+		server->serverFormat.blueMax  = 3;
 	} else {
-		server->rfbServerFormat.redShift = 0;
+		server->serverFormat.redShift = 0;
 		if ( framebufferImage->red_mask )
-			while ( ! ( framebufferImage->red_mask & (1 << server->rfbServerFormat.redShift) ) )
-				server->rfbServerFormat.redShift++;
-		server->rfbServerFormat.greenShift = 0;
+			while ( ! ( framebufferImage->red_mask & (1 << server->serverFormat.redShift) ) )
+				server->serverFormat.redShift++;
+		server->serverFormat.greenShift = 0;
 		if ( framebufferImage->green_mask )
-			while ( ! ( framebufferImage->green_mask & (1 << server->rfbServerFormat.greenShift) ) )
-				server->rfbServerFormat.greenShift++;
-		server->rfbServerFormat.blueShift = 0;
+			while ( ! ( framebufferImage->green_mask & (1 << server->serverFormat.greenShift) ) )
+				server->serverFormat.greenShift++;
+		server->serverFormat.blueShift = 0;
 		if ( framebufferImage->blue_mask )
-			while ( ! ( framebufferImage->blue_mask & (1 << server->rfbServerFormat.blueShift) ) )
-				server->rfbServerFormat.blueShift++;
-		server->rfbServerFormat.redMax   = framebufferImage->red_mask   >> server->rfbServerFormat.redShift;
-		server->rfbServerFormat.greenMax = framebufferImage->green_mask >> server->rfbServerFormat.greenShift;
-		server->rfbServerFormat.blueMax  = framebufferImage->blue_mask  >> server->rfbServerFormat.blueShift;
+			while ( ! ( framebufferImage->blue_mask & (1 << server->serverFormat.blueShift) ) )
+				server->serverFormat.blueShift++;
+		server->serverFormat.redMax   = framebufferImage->red_mask   >> server->serverFormat.redShift;
+		server->serverFormat.greenMax = framebufferImage->green_mask >> server->serverFormat.greenShift;
+		server->serverFormat.blueMax  = framebufferImage->blue_mask  >> server->serverFormat.blueShift;
 	}
 
 	server->frameBuffer = fb;
@@ -496,7 +500,9 @@ void RFBController::startServer(int inetdFd, bool xtestGrab)
 	server->kbdAddEvent = keyboardHook;
 	server->ptrAddEvent = pointerHook;
 	server->newClientHook = newClientHook;
+#ifdef USE_MODIFIED_BUILTIN_LIBVNCSERVER
 	server->inetdDisconnectHook = inetdDisconnectHook;
+#endif // USE_MODIFIED_BUILTIN_LIBVNCSERVER
 	server->passwordCheck = passwordCheck;
 	server->setXCutText = clipboardHook;
 
@@ -511,7 +517,7 @@ void RFBController::startServer(int inetdFd, bool xtestGrab)
 	scanner = new XUpdateScanner(tqt_xdisplay(),
 				     TQApplication::desktop()->winId(),
 				     (unsigned char*)fb, w, h,
-				     server->rfbServerFormat.bitsPerPixel,
+				     server->serverFormat.bitsPerPixel,
 				     server->paddedWidthInBytes,
 				     !configuration->disableXShm());
 
@@ -551,9 +557,9 @@ void RFBController::connectionAccepted(bool aRC)
 	initIdleTimer.stop();
 	idleTimer.start(IDLE_PAUSE);
 
-	server->rfbClientHead->clientGoneHook = clientGoneHook;
+	server->clientHead->clientGoneHook = clientGoneHook;
 	state = RFB_CONNECTED;
-	if (!server->rfbAuthPasswdData)
+	if (!server->authPasswdData)
 	        emit sessionEstablished(remoteIp);
 }
 
@@ -567,7 +573,8 @@ void RFBController::acceptConnection(bool aRemoteControl)
 		return;
 
 	connectionAccepted(aRemoteControl);
-	rfbStartOnHoldClient(server->rfbClientHead);
+	rfbStartOnHoldClient(server->clientHead);
+	server->clientHead->onHold = false;
 }
 
 void RFBController::refuseConnection()
@@ -578,7 +585,7 @@ void RFBController::refuseConnection()
 
 	if (state != RFB_CONNECTING)
 		return;
-	rfbRefuseOnHoldClient(server->rfbClientHead);
+	rfbRefuseOnHoldClient(server->clientHead);
 	state = RFB_WAITING;
 }
 
@@ -643,7 +650,7 @@ void RFBController::closeConnection()
 		if (!checkAsyncEvents()) {
 			asyncMutex.lock();
 			if (!closePending)
-				rfbCloseClient(server->rfbClientHead);
+				rfbCloseClient(server->clientHead);
 			asyncMutex.unlock();
 		}
 	}
@@ -664,8 +671,6 @@ void RFBController::idleSlot()
 	if (checkAsyncEvents() || forcedClose)
 		return;
 
-	rfbUndrawCursor(server);
-
 	TQPtrList<Hint> v;
 	v.setAutoDelete(true);
 	TQPoint p = TQCursor::pos();
@@ -681,7 +686,7 @@ void RFBController::idleSlot()
 
 	asyncMutex.lock();
 	if (!closePending)
-		defaultPtrAddEvent(0, p.x(),p.y(), server->rfbClientHead);
+		rfbDefaultPtrAddEvent(0, p.x(),p.y(), server->clientHead);
 	asyncMutex.unlock();
 
 	checkAsyncEvents(); // check 2nd time (see 3rd line)
@@ -717,7 +722,7 @@ bool checkPassword(const TQString &p,
 		strncpy(passwd, p.latin1(),
 			(MAXPWLEN <= p.length()) ? MAXPWLEN : p.length());
 
-	vncEncryptBytes(challenge, passwd);
+	rfbEncryptBytes(challenge, passwd);
 	return memcmp(challenge, response, len) == 0;
 }
 
@@ -770,7 +775,9 @@ bool RFBController::handleCheckPassword(rfbClientPtr cl,
 enum rfbNewClientAction RFBController::handleNewClient(rfbClientPtr cl)
 {
 	int socket = cl->sock;
+#ifdef USE_MODIFIED_BUILTIN_LIBVNCSERVER
 	cl->negotiationFinishedHook = negotiationFinishedHook;
+#endif // USE_MODIFIED_BUILTIN_LIBVNCSERVER
 
 	TQString host, port;
 	TDESocketAddress *ksa = KExtendedSocket::peerAddress(socket);
@@ -826,12 +833,14 @@ void RFBController::handleClientGone()
 	asyncMutex.unlock();
 }
 
+#ifdef USE_MODIFIED_BUILTIN_LIBVNCSERVER
 void RFBController::handleNegotiationFinished(rfbClientPtr cl)
 {
 	asyncMutex.lock();
 	disableBackgroundPending = cl->disableBackground;
 	asyncMutex.unlock();
 }
+#endif // USE_MODIFIED_BUILTIN_LIBVNCSERVER
 
 void RFBController::handleKeyEvent(bool down, KeySym keySym) {
 	if (!allowDesktopControl)
@@ -907,7 +916,7 @@ void RFBController::passwordChanged() {
 		(configuration->password().length() != 0) ||
 		(configuration->invitations().count() > 0);
 
-	server->rfbAuthPasswdData = (void*) (authRequired ? 1 : 0);
+	server->authPasswdData = (void*) (authRequired ? 1 : 0);
 }
 
 void RFBController::sendKNotifyEvent(const TQString &n, const TQString &d)
