@@ -210,7 +210,7 @@ KSCD::KSCD( TQWidget *parent, const char *name )
 
   setDocking(Prefs::docking());
 
-  setFocusPolicy(TQ_NoFocus);
+  setFocusPolicy(TQWidget::NoFocus);
 
   songListCB->setSizePolicy(TQSizePolicy::Ignored, TQSizePolicy::Fixed);
   adjustSize();
