@@ -11,7 +11,7 @@ class PPushButton;
 
 class PPushButton : public PButton
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   static PObject *createWidget(CreateArgs &ca);
