@@ -88,7 +88,7 @@ class CustomCatalog;
 
 class KStarsData : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	//Friend classes can see the private data.
