@@ -20,7 +20,7 @@
 
 #include <ktnef/ktnefpropertyset.h>
 #include <tqptrlist.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class KTNEFAttach;
 
