@@ -486,7 +486,7 @@ void RandomQueryDlg::slotTransChanged(const TQString&)
 {
   mw->verify->setDefault(true);
   bool suggestions = Prefs::suggestions();
-  if ( suggestions && sender() && TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())) -> isA (TQCOMBOBOX_OBJECT_NAME_STRING) )
+  if ( suggestions && sender() && sender() -> isA ("TQComboBox") )
   {
     TQLineEdit* edit = ((TQComboBox*) sender()) -> lineEdit();
     resetField (edit);
@@ -497,7 +497,7 @@ void RandomQueryDlg::slotTransChanged(const TQString&)
     else
       mw->status -> clear();
   }
-  else if ( ! suggestions && sender() && TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())) -> isA (TQLINEEDIT_OBJECT_NAME_STRING) )
+  else if ( ! suggestions && sender() && sender() -> isA ("TQLineEdit") )
     resetField ((TQLineEdit*) sender());
 }
 
