@@ -28,7 +28,7 @@
 */
 class MultipleView : public MultipleViewBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     MultipleView(TQWidget *parent = 0, const char *name = 0, WFlags f = 0);
