@@ -82,9 +82,6 @@
 #include <libxml/xmlerror.h>
 #include <libxml/HTMLtree.h>
 #include <libxml/xmlIO.h>
-#ifdef LIBXML_DOCB_ENABLED
-#include <libxml/DOCBparser.h>
-#endif
 #ifdef LIBXML_XINCLUDE_ENABLED
 #include <libxml/xinclude.h>
 #endif
@@ -975,22 +972,11 @@ xsldbgLoadXmlData(void)
 #endif
 #ifdef LIBXML_DOCB_ENABLED
     if (optionsGetIntOption(OPTIONS_DOCBOOK))
-#       if LIBXML_VERSION >= 20600
         doc = xmlParseFile((char *) optionsGetStringOption(OPTIONS_DATA_FILE_NAME));
-#       else
-        doc = docbParseFile((char *)
-                            optionsGetStringOption(OPTIONS_DATA_FILE_NAME),
-                            NULL);
-#       endif
     else
 #endif
-
-#if LIBXML_VERSION >= 20600
         doc = xmlSAXParseFile(&mySAXHandler,
 			     (char *) optionsGetStringOption(OPTIONS_DATA_FILE_NAME), 0);
-#else
-        doc = xmlParseFile((char *) optionsGetStringOption(OPTIONS_DATA_FILE_NAME));
-#endif
     if (doc == NULL) {
         xsldbgGenericErrorFunc(i18n("Error: Unable to parse file %1.\n").arg(xsldbgUrl(optionsGetStringOption(OPTIONS_DATA_FILE_NAME))));
         if (!optionsGetIntOption(OPTIONS_SHELL)) {
@@ -1031,11 +1017,7 @@ xsldbgLoadXmlTemporary(const xmlChar * path)
 #endif
 #ifdef LIBXML_DOCB_ENABLED
     if (optionsGetIntOption(OPTIONS_DOCBOOK))
-#       if LIBXML_VERSION >= 20600
         doc = xmlParseFile((char *) path);
-#       else
-        doc = docbParseFile((char *) path, NULL);
-#       endif
     else
 #endif
         doc = xmlSAXParseFile(&mySAXhdlr, (char *) path, 0);
@@ -1100,7 +1082,7 @@ handler_routine(DWORD dwCtrlType)
 
 #endif
 
-#if LIBXML_VERSION >= 2006000
+#if 0
 /* libxml/ handlers */
 void xsldbgStructErrorHandler(void * userData, xmlErrorPtr error)
 {
@@ -1230,13 +1212,8 @@ xsldbgInit()
         /* set up the parser */
         xmlInitParser();
 #if 0
-#if LIBXML_VERSION >= 20600
      xmlSetGenericErrorFunc(NULL,  NULL);
      xmlSetStructuredErrorFunc(NULL , (xmlStructuredErrorFunc)xsldbgStructErrorHandler);
-#else
-        xmlSetGenericErrorFunc(0, xsldbgGenericErrorFunc);
-        xsltSetGenericErrorFunc(0, xsldbgGenericErrorFunc);
-#endif    
 #else
         xmlSetGenericErrorFunc(0, xsldbgGenericErrorFunc);
         xsltSetGenericErrorFunc(0, xsldbgGenericErrorFunc);
