@@ -8,7 +8,7 @@
 
 class %{APPNAME}: public TDECModule
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
