@@ -63,7 +63,7 @@ KMdiChildView::KMdiChildView( const TQString& caption, TQWidget* parentWidget, c
 		m_szCaption = i18n( "Unnamed" );
 	
 	m_sTabCaption = m_szCaption;
-	setFocusPolicy( TQ_ClickFocus );
+	setFocusPolicy( TQWidget::ClickFocus );
 	installEventFilter( this );
 	
 	// store the current time
@@ -87,7 +87,7 @@ KMdiChildView::KMdiChildView( TQWidget* parentWidget, const char* name, WFlags f
 	setGeometry( 0, 0, 0, 0 );  // reset
 	m_szCaption = i18n( "Unnamed" );
 	m_sTabCaption = m_szCaption;
-	setFocusPolicy( TQ_ClickFocus );
+	setFocusPolicy( TQWidget::ClickFocus );
 	installEventFilter( this );
 
 	// store the current time
@@ -362,7 +362,7 @@ void KMdiChildView::youAreDetached()
 	if ( myIconPtr() )
 		setIcon( *( myIconPtr() ) );
 	
-	setFocusPolicy( TQ_StrongFocus );
+	setFocusPolicy( TQWidget::StrongFocus );
 
 	emit isDetachedNow();
 }
@@ -492,7 +492,7 @@ void KMdiChildView::slot_childDestroyed()
 
 	// if we lost a child we uninstall ourself as event filter for the lost
 	// child and its children
-	const TQObject * pLostChild = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(TQT_BASE_OBJECT_NAME::sender()));
+	const TQObject * pLostChild = TQObject::sender();
 	if ( pLostChild && ( pLostChild->isWidgetType() ) )
 	{
 		TQObjectList* list = ( ( TQObject* ) ( pLostChild ) ) ->queryList( "TQWidget" );
@@ -526,8 +526,8 @@ bool KMdiChildView::eventFilter( TQObject *obj, TQEvent *e )
 		if ( ke->key() == TQt::Key_Tab )
 		{
 			TQWidget* w = ( TQWidget* ) obj;
-			TQ_FocusPolicy wfp = w->focusPolicy();
-			if ( wfp == TQ_StrongFocus || wfp == TQ_TabFocus || w->focusPolicy() == TQ_WheelFocus )
+			TQWidget::FocusPolicy wfp = w->focusPolicy();
+			if ( wfp == TQWidget::StrongFocus || wfp == TQWidget::TabFocus || w->focusPolicy() == TQWidget::WheelFocus )
 			{
 				if ( m_lastFocusableChildWidget != 0 )
 				{
@@ -577,8 +577,8 @@ bool KMdiChildView::eventFilter( TQObject *obj, TQEvent *e )
 				TQWidget * widg = ( TQWidget* ) o;
 				++it;
 				widg->removeEventFilter( this );
-				TQ_FocusPolicy wfp = widg->focusPolicy();
-				if ( wfp == TQ_StrongFocus || wfp == TQ_TabFocus || widg->focusPolicy() == TQ_WheelFocus )
+				TQWidget::FocusPolicy wfp = widg->focusPolicy();
+				if ( wfp == TQWidget::StrongFocus || wfp == TQWidget::TabFocus || widg->focusPolicy() == TQWidget::WheelFocus )
 				{
 					if ( m_firstFocusableChildWidget == widg )
 						m_firstFocusableChildWidget = 0L;   // reset first widget
@@ -611,8 +611,8 @@ bool KMdiChildView::eventFilter( TQObject *obj, TQEvent *e )
 				++it;
 				widg->installEventFilter( this );
 				connect( widg, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slot_childDestroyed() ) );
-				TQ_FocusPolicy wfp = widg->focusPolicy();
-				if ( wfp == TQ_StrongFocus || wfp == TQ_TabFocus || widg->focusPolicy() == TQ_WheelFocus )
+				TQWidget::FocusPolicy wfp = widg->focusPolicy();
+				if ( wfp == TQWidget::StrongFocus || wfp == TQWidget::TabFocus || widg->focusPolicy() == TQWidget::WheelFocus )
 				{
 					if ( m_firstFocusableChildWidget == 0 )
 						m_firstFocusableChildWidget = widg;  // first widge
@@ -628,14 +628,14 @@ bool KMdiChildView::eventFilter( TQObject *obj, TQEvent *e )
 		if ( e->type() == TQEvent::IconChange )
 		{
 			//            tqDebug("KMDiChildView:: TQEvent:IconChange intercepted\n");
-			if ( TQT_BASE_OBJECT(obj) == this )
+			if ( obj == this )
 				iconUpdated( this, icon() ? ( *icon() ) : TQPixmap() );
-			else if ( TQT_BASE_OBJECT(obj) == m_trackChanges )
+			else if ( obj == m_trackChanges )
 				setIcon( m_trackChanges->icon() ? ( *( m_trackChanges->icon() ) ) : TQPixmap() );
 		}
 		if ( e->type() == TQEvent::CaptionChange )
 		{
-			if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(this) )
+			if ( obj == this )
 				captionUpdated( this, caption() );
 		}
 	}
