@@ -440,7 +440,7 @@ void tqt_leave_modal( TQWidget *widget );
 void QExtFileInfo::enter_loop()
 {
   TQWidget dummy(0,0,WType_Dialog | WShowModal);
-  dummy.setFocusPolicy( TQ_NoFocus );
+  dummy.setFocusPolicy( TQWidget::NoFocus );
   tqt_enter_modal(&dummy);
   //kdDebug(24000)<<"QExtFileInfo::enter_loop:before tqApp->enter_loop()"<< endl;
   tqApp->enter_loop();
