@@ -34,6 +34,8 @@
 
 #include <ksimpleconfig.h>
 
+#include "konq_sort_constants.h"
+
 static TQPixmap wallpaperPixmap( const TQString & _wallpaper )
 {
     TQString key = "wallpapers/";
@@ -65,9 +67,11 @@ static TQPixmap wallpaperPixmap( const TQString & _wallpaper )
 struct KonqPropsView::Private
 {
    TQStringList* previewsToShow;
+   TextSortOrder textSortOrder;
    bool previewsEnabled:1;
    bool caseInsensitiveSort:1;
    bool dirsfirst:1;
+   bool hiddenfirst:1;
    bool descending:1;
    TQString sortcriterion;
 };
@@ -90,7 +94,9 @@ KonqPropsView::KonqPropsView( TDEInstance * instance, KonqPropsView * defaultPro
   m_iIconSize = config->readNumEntry( "IconSize", 0 );
   m_iItemTextPos = config->readNumEntry( "ItemTextPos", TQIconView::Bottom );
   d->sortcriterion = config->readEntry( "SortingCriterion", "sort_nci" );
+  d->textSortOrder = (TextSortOrder) config->readNumEntry( "TextSortOrder", 1 );
   d->dirsfirst = config->readBoolEntry( "SortDirsFirst", true );
+  d->hiddenfirst = config->readBoolEntry( "SortHiddenFirst", true );
   d->descending = config->readBoolEntry( "SortDescending", false );
   m_bShowDot = config->readBoolEntry( "ShowDotFiles", false );
   m_bShowDirectoryOverlays = config->readBoolEntry( "ShowDirectoryOverlays", false );
@@ -138,11 +144,21 @@ bool KonqPropsView::isCaseInsensitiveSort() const
    return d->caseInsensitiveSort;
 }
 
+TextSortOrder KonqPropsView::getSortOrder() const
+{
+   return d->textSortOrder;
+}
+
 bool KonqPropsView::isDirsFirst() const
 {
    return d->dirsfirst;
 }
 
+bool KonqPropsView::isHiddenFirst() const
+{
+   return d->hiddenfirst;
+}
+
 bool KonqPropsView::isDescending() const
 {
    return d->descending;
@@ -199,7 +215,9 @@ bool KonqPropsView::enterDir( const KURL & dir )
     m_iIconSize = m_defaultProps->iconSize();
     m_iItemTextPos = m_defaultProps->itemTextPos();
     d->sortcriterion = m_defaultProps->sortCriterion();
+    d->textSortOrder = m_defaultProps->getSortOrder();
     d->dirsfirst = m_defaultProps->isDirsFirst();
+    d->hiddenfirst = m_defaultProps->isHiddenFirst();
     d->descending = m_defaultProps->isDescending();
     m_bShowDot = m_defaultProps->isShowingDotFiles();
     d->caseInsensitiveSort=m_defaultProps->isCaseInsensitiveSort();
@@ -218,7 +236,9 @@ bool KonqPropsView::enterDir( const KURL & dir )
     m_iIconSize = config->readNumEntry( "IconSize", m_iIconSize );
     m_iItemTextPos = config->readNumEntry( "ItemTextPos", m_iItemTextPos );
     d->sortcriterion = config->readEntry( "SortingCriterion" , d->sortcriterion );
+    d->textSortOrder = (TextSortOrder) config->readNumEntry( "TextSortOrder", d->textSortOrder );
     d->dirsfirst = config->readBoolEntry( "SortDirsFirst", d->dirsfirst );
+    d->hiddenfirst = config->readBoolEntry( "SortHiddenFirst", d->hiddenfirst );
     d->descending = config->readBoolEntry( "SortDescending", d->descending );
     m_bShowDot = config->readBoolEntry( "ShowDotFiles", m_bShowDot );
     d->caseInsensitiveSort=config->readBoolEntry("CaseInsensitiveSort",d->caseInsensitiveSort);
@@ -315,6 +335,20 @@ void KonqPropsView::setSortCriterion( const TQString &criterion )
     }
 }
 
+void KonqPropsView::setSortOrder( TextSortOrder order)
+{
+    d->textSortOrder = order;
+    if ( m_defaultProps && !m_bSaveViewPropertiesLocally ) {
+        m_defaultProps->setSortOrder( order );
+    }
+    else if (currentConfig())
+    {
+        TDEConfigGroupSaver cgs(currentConfig(), currentGroup());
+        currentConfig()->writeEntry( "TextSortOrder", d->textSortOrder );
+        currentConfig()->sync();
+    }
+}
+
 void KonqPropsView::setDirsFirst( bool first)
 {
     d->dirsfirst = first;
@@ -328,6 +362,19 @@ void KonqPropsView::setDirsFirst( bool first)
     }
 }
 
+void KonqPropsView::setHiddenFirst(bool first)
+{
+    d->hiddenfirst = first;
+    if ( m_defaultProps && !m_bSaveViewPropertiesLocally )
+        m_defaultProps->setHiddenFirst( first );
+    else if (currentConfig())
+    {
+        TDEConfigGroupSaver cgs(currentConfig(), currentGroup());
+        currentConfig()->writeEntry( "SortHiddenFirst", d->hiddenfirst );
+        currentConfig()->sync();
+    }
+}
+
 void KonqPropsView::setDescending( bool descend)
 {
     d->descending = descend;
