@@ -54,7 +54,7 @@ class Identity;
 class IdentityManager : public ConfigManager, public DCOPObject
 #undef IdentityManager
 {
-  Q_OBJECT
+  TQ_OBJECT
 //  
   K_DCOP
 
