@@ -32,7 +32,7 @@ namespace KPIM {
 
 class KDE_EXPORT CategorySelectDialog : public KDialogBase
 { 
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     CategorySelectDialog( KPimPrefs *prefs, TQWidget *parent = 0,
