@@ -57,7 +57,7 @@ class KURLRequester;
 */
 class KDE_EXPORT KPrefsWid : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     /**
@@ -278,7 +278,7 @@ class KDE_EXPORT KPrefsWidDate : public KPrefsWid
 */
 class KDE_EXPORT KPrefsWidColor : public KPrefsWid
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     /**
@@ -321,7 +321,7 @@ class KDE_EXPORT KPrefsWidColor : public KPrefsWid
 */
 class KDE_EXPORT KPrefsWidFont : public KPrefsWid
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     /**
@@ -720,7 +720,7 @@ class KDE_EXPORT KPrefsWidManager
 */
 class KDE_EXPORT KPrefsDialog : public KDialogBase, public KPrefsWidManager
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     /**
@@ -774,7 +774,7 @@ class KDE_EXPORT KPrefsDialog : public KDialogBase, public KPrefsWidManager
 
 class KDE_EXPORT KPrefsModule : public TDECModule, public KPrefsWidManager
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     KPrefsModule( TDEConfigSkeleton *, TQWidget *parent = 0, const char *name = 0 );
