@@ -37,7 +37,7 @@ namespace KParts
    **/
   class KDE_EXPORT SideBarExtension : public TQObject
   {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
