@@ -13,7 +13,7 @@
 // We are hot - unistd.h should have turned on the specific APIs we requested
 
 
-#ifdef QT_THREAD_SUPPORT
+#ifdef TQT_THREAD_SUPPORT
 #include <pthread.h>
 #endif
 
@@ -45,7 +45,7 @@
 #include <resolv.h>
 
 
-#if !defined(QT_NO_COMPAT)
+#if !defined(TQT_NO_COMPAT)
 #define QT_STATBUF		struct stat
 #define QT_STATBUF4TSTAT	struct stat
 #define QT_STAT			::stat
