@@ -8,7 +8,7 @@ class TQDialog;
 
 class ReplaceDlgImpl : public ReplaceDlg
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
