@@ -50,6 +50,6 @@ bool MNGFormat::installIOHandler( const TQString &name )
     return TRUE;
 }
 
-Q_EXPORT_PLUGIN( MNGFormat )
+TQ_EXPORT_PLUGIN( MNGFormat )
 
 #endif // TQT_NO_IMAGEFORMATPLUGIN
