@@ -687,7 +687,7 @@ UnixMakefileGenerator::writeMakeParts(TQTextStream &t)
 	//moc itself shouldn't have this dependency - this is a little kludgy but it is
 	//better than the alternative for now.
 	TQString moc = project->first("QMAKE_MOC"), target = project->first("TARGET"),
-	    moc_dir = "$(QTDIR)/src/moc";
+	    moc_dir = "$(TQTDIR)/src/moc";
 	if(!project->isEmpty("QMAKE_MOC_SRC"))
 	    moc_dir = project->first("QMAKE_MOC_SRC");
 	fixEnvVariables(target);
@@ -922,7 +922,7 @@ UnixMakefileGenerator::writeMakeParts(TQTextStream &t)
 	  << outdir << "allmoc.cpp: " << precomph << " "
 	  << varList("HEADERS_ORIG") << "\n\t"
 	  << "echo '#include \"" << precomph << "\"' >" << outdir << "allmoc.cpp" << "\n\t"
-	  << "$(CXX) -E -DQT_MOC_CPP -DQT_NO_STL $(CXXFLAGS) $(INCPATH) >" << outdir << "allmoc.h "
+	  << "$(CXX) -E -DQT_MOC_CPP -DTQT_NO_STL $(CXXFLAGS) $(INCPATH) >" << outdir << "allmoc.h "
 	  << outdir << "allmoc.cpp" << "\n\t"
 	  << "$(MOC) -o " << outdir << "allmoc.cpp " << outdir << "allmoc.h" << "\n\t"
 	  << "perl -pi -e 's{#include \"allmoc.h\"}{#define QT_H_CPP\\n#include \""
@@ -1534,7 +1534,7 @@ UnixMakefileGenerator::pkgConfigFixPath(TQString path) const
 }
 
 void
-UnixMakefileGenerator::writePkgConfigFile()     // ### does make sense only for libqt so far
+UnixMakefileGenerator::writePkgConfigFile()     // ### does make sense only for libtqt so far
 {
     TQString fname = pkgConfigFileName(), lname = fname;
     int slsh = lname.findRev(Option::dir_sep);
@@ -1546,23 +1546,38 @@ UnixMakefileGenerator::writePkgConfigFile()     // ### does make sense only for
     project->variables()["ALL_DEPS"].append(fname);
     TQTextStream t(&ft);
 
-    TQString prefix = pkgConfigPrefix();
-    TQString libDir = project->first("QMAKE_PKGCONFIG_LIBDIR");
-    if(libDir.isEmpty())
-	libDir = prefix + "/lib";
-    TQString includeDir = project->first("QMAKE_PKGCONFIG_INCDIR");
-    if(includeDir.isEmpty())
-	includeDir = prefix + "/include";
-    TQString pluginsDir = project->first("QMAKE_PKGCONFIG_PLUGINS");
-    if(pluginsDir.isEmpty())
-	pluginsDir = prefix + "/plugins";
+	TQString prefix = pkgConfigPrefix();
+	TQString libDir = tqInstallPathLibs();
+	if (libDir.isEmpty())
+	{
+		libDir = prefix + "/lib";
+	}
+	TQString includeDir = tqInstallPathHeaders();
+	if (includeDir.isEmpty())
+	{
+		includeDir = prefix + "/include";
+	}
+	TQString pluginsDir = tqInstallPathPlugins();
+	if (pluginsDir.isEmpty())
+	{
+		pluginsDir = prefix + "/plugins";
+	}
+	TQString translationsDir = tqInstallPathTranslations();
+	if (translationsDir.isEmpty())
+	{
+		translationsDir = prefix + "/translations";
+	}
+
+	t << "prefix=" << prefix << endl
+	  << "exec_prefix=${prefix}" << endl
+	  << "libdir=" << pkgConfigFixPath(libDir) << endl
+	  << "includedir=" << pkgConfigFixPath(includeDir) << endl
+	  // non-standard entry. Provides path for plugins
+	  << "pluginsdir=" << pkgConfigFixPath(pluginsDir) << endl
+	  // non-standard entry. Provides path for translations
+	  << "translationsdir=" << pkgConfigFixPath(translationsDir) << endl
+	  << endl;
 
-    t << "prefix=" << prefix << endl;
-    t << "exec_prefix=${prefix}\n"
-      << "libdir=" << pkgConfigFixPath(libDir) << "\n"
-      << "includedir=" << pkgConfigFixPath(includeDir) << endl;
-    // non-standard entry. Provides path for plugins
-    t << "pluginsdir=" << pkgConfigFixPath(pluginsDir) << endl;
     // non-standard entry. Provides useful info normally only
     // contained in the internal .qmake.cache file
     t << varGlue("CONFIG", "qt_config=", " ", "") << endl << endl;
