@@ -23,15 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQGENERIC_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
 #include <ntqgeneric.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-#endif // USE_QT4
-
 #endif /* TQT_TQGENERIC_H */
