@@ -21,14 +21,3 @@ Boston, MA 02110-1301, USA.
 
 #include <tqt.h>
 #include <ntqtabbar.h>
-
-#ifdef USE_QT4
-
-int QTabBar::tabAt(const int &pos) const {
-	#warning "tabAt(const int &pos) unimplemented!!!"
-	// FIXME
-	// What is the correct function to call here???
-	//return tabAt(QPoint(pos));
-}
-
-#endif // USE_QT4
