@@ -303,7 +303,7 @@ BaseTreeView::BaseTreeView(TQWidget *parent, const char *name)
   setLineWidth(2);
   setFullWidth(true);
   setShowSortIndicator(true);
-  setFocusPolicy(TQ_ClickFocus);
+  setFocusPolicy(TQWidget::ClickFocus);
   setShowFolderOpenPixmap(false);
 
   connect(this, TQT_SIGNAL(returnPressed(TQListViewItem *)),
@@ -554,7 +554,7 @@ void BaseTreeView::slotOpenWith()
 
 void BaseTreeView::slotOpenWithApplication()
 {
-  KService::Ptr ptr = KService::serviceByDesktopPath(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name());
+  KService::Ptr ptr = KService::serviceByDesktopPath(sender()->name());
   if (ptr)
   {
     KURL::List list;
