@@ -165,7 +165,7 @@ With arg, to it arg times."
       (and (re-search-backward "^class[ \t]" nil t)
            (progn
              (forward-word 1)
-             (while (looking-at "[ \t]*Q_EXPORT")
+             (while (looking-at "[ \t]*TQ_EXPORT")
                (forward-word 2))
              (while (looking-at "[ \t]")
                (forward-char 1))
@@ -1618,7 +1618,7 @@ With arg, to it arg times."
             (re-search-backward "^class \\([a-zA-Z0-9_]+\\)[ \t]*\\([a-zA-Z0-9_]*\\)" nil t)
             (set class (match-string 1))
             (set save (match-string 2))
-            (and (string-match "Q_EXPORT" class)
+            (and (string-match "TQ_EXPORT" class)
                  (set class save))
             (message (concat class "::" fn))
             )
