@@ -40,7 +40,7 @@
 
 #include "ntqcolordialog.h"
 
-#ifndef QT_NO_COLORDIALOG
+#ifndef TQT_NO_COLORDIALOG
 
 #include "ntqpainter.h"
 #include "ntqlayout.h"
@@ -64,7 +64,7 @@ TQColor macGetColor( const TQColor& initial, TQWidget *parent, const char *name
 #endif
 
 #ifdef Q_WS_X11
-#include "private/qtkdeintegration_x11_p.h"
+#include "private/tqttdeintegration_x11_p.h"
 #endif
 
 //////////// TQWellArray BEGIN
@@ -529,7 +529,7 @@ protected:
     void mousePressEvent( TQMouseEvent *e );
     void mouseMoveEvent( TQMouseEvent *e );
     void mouseReleaseEvent( TQMouseEvent *e );
-#ifndef QT_NO_DRAGANDDROP
+#ifndef TQT_NO_DRAGANDDROP
     void dragEnterEvent( TQDragEnterEvent *e );
     void dragLeaveEvent( TQDragLeaveEvent *e );
     void dragMoveEvent( TQDragMoveEvent *e );
@@ -561,7 +561,7 @@ void TQColorWell::mousePressEvent( TQMouseEvent *e )
 void TQColorWell::mouseMoveEvent( TQMouseEvent *e )
 {
     TQWellArray::mouseMoveEvent( e );
-#ifndef QT_NO_DRAGANDDROP
+#ifndef TQT_NO_DRAGANDDROP
     if ( !mousePressed )
 	return;
     if ( ( pressPos - e->pos() ).manhattanLength() > TQApplication::startDragDistance() ) {
@@ -581,7 +581,7 @@ void TQColorWell::mouseMoveEvent( TQMouseEvent *e )
 #endif
 }
 
-#ifndef QT_NO_DRAGANDDROP
+#ifndef TQT_NO_DRAGANDDROP
 void TQColorWell::dragEnterEvent( TQDragEnterEvent *e )
 {
     setFocus();
@@ -620,7 +620,7 @@ void TQColorWell::dropEvent( TQDropEvent *e )
     }
 }
 
-#endif // QT_NO_DRAGANDDROP
+#endif // TQT_NO_DRAGANDDROP
 
 void TQColorWell::mouseReleaseEvent( TQMouseEvent *e )
 {
@@ -987,7 +987,7 @@ protected:
     void mousePressEvent( TQMouseEvent *e );
     void mouseMoveEvent( TQMouseEvent *e );
     void mouseReleaseEvent( TQMouseEvent *e );
-#ifndef QT_NO_DRAGANDDROP
+#ifndef TQT_NO_DRAGANDDROP
     void dragEnterEvent( TQDragEnterEvent *e );
     void dragLeaveEvent( TQDragLeaveEvent *e );
     void dropEvent( TQDropEvent *e );
@@ -1024,7 +1024,7 @@ void TQColorShowLabel::mousePressEvent( TQMouseEvent *e )
 
 void TQColorShowLabel::mouseMoveEvent( TQMouseEvent *e )
 {
-#ifndef QT_NO_DRAGANDDROP
+#ifndef TQT_NO_DRAGANDDROP
     if ( !mousePressed )
 	return;
     if ( ( pressPos - e->pos() ).manhattanLength() > TQApplication::startDragDistance() ) {
@@ -1041,7 +1041,7 @@ void TQColorShowLabel::mouseMoveEvent( TQMouseEvent *e )
 #endif
 }
 
-#ifndef QT_NO_DRAGANDDROP
+#ifndef TQT_NO_DRAGANDDROP
 void TQColorShowLabel::dragEnterEvent( TQDragEnterEvent *e )
 {
     if ( TQColorDrag::canDecode( e ) )
@@ -1065,7 +1065,7 @@ void TQColorShowLabel::dropEvent( TQDropEvent *e )
 	e->ignore();
     }
 }
-#endif // QT_NO_DRAGANDDROP
+#endif // TQT_NO_DRAGANDDROP
 
 void TQColorShowLabel::mouseReleaseEvent( TQMouseEvent * )
 {
@@ -1459,7 +1459,7 @@ TQColorDialog::TQColorDialog(TQWidget* parent, const char* name, bool modal) :
     setSizeGripEnabled( FALSE );
     d = new TQColorDialogPrivate( this );
 
-#ifndef QT_NO_SETTINGS
+#ifndef TQT_NO_SETTINGS
     if ( !customSet ) {
 	TQSettings settings;
 	settings.insertSearchPath( TQSettings::Windows, "/Trolltech" );
@@ -1486,15 +1486,15 @@ TQColor TQColorDialog::getColor( const TQColor& initial, TQWidget *parent,
 			       const char *name )
 {
 #if defined(Q_WS_X11)
-    if( TQKDEIntegration::enabled())
-        return TQKDEIntegration::getColor( initial, parent, name );
+    if( TQTDEIntegration::enabled())
+        return TQTDEIntegration::getColor( initial, parent, name );
 #elif defined(Q_WS_MAC)
     return macGetColor(initial, parent, name);
 #endif
 
     int allocContext = TQColor::enterAllocContext();
     TQColorDialog *dlg = new TQColorDialog( parent, name, TRUE );  //modal
-#ifndef QT_NO_WIDGET_TOPEXTRA
+#ifndef TQT_NO_WIDGET_TOPEXTRA
     dlg->setCaption( TQColorDialog::tr( "Select color" ) );
 #endif
     dlg->setColor( initial );
@@ -1526,8 +1526,8 @@ TQRgb TQColorDialog::getRgba( TQRgb initial, bool *ok,
 			    TQWidget *parent, const char* name )
 {
 #if defined(Q_WS_MAC)
-    if( TQKDEIntegration::enabled()) {
-        TQColor color = TQKDEIntegration::getColor( TQColor( initial ), parent, name );
+    if( TQTDEIntegration::enabled()) {
+        TQColor color = TQTDEIntegration::getColor( TQColor( initial ), parent, name );
         if( ok )
             *ok = color.isValid();
         return color.rgba();
@@ -1540,7 +1540,7 @@ TQRgb TQColorDialog::getRgba( TQRgb initial, bool *ok,
     TQColorDialog *dlg = new TQColorDialog( parent, name, TRUE );  //modal
 
     TQ_CHECK_PTR( dlg );
-#ifndef QT_NO_WIDGET_TOPEXTRA
+#ifndef TQT_NO_WIDGET_TOPEXTRA
     dlg->setCaption( TQColorDialog::tr( "Select color" ) );
 #endif
     dlg->setColor( initial );
@@ -1584,7 +1584,7 @@ TQColor TQColorDialog::color() const
 
 TQColorDialog::~TQColorDialog()
 {
-#ifndef QT_NO_SETTINGS
+#ifndef TQT_NO_SETTINGS
     if ( !customSet ) {
 	TQSettings settings;
 	settings.insertSearchPath( TQSettings::Windows, "/Trolltech" );
