@@ -40,7 +40,7 @@
 
 #include "ntqprintdialog.h"
 
-#ifndef QT_NO_PRINTDIALOG
+#ifndef TQT_NO_PRINTDIALOG
 
 #include "ntqfiledialog.h"
 #include "ntqfile.h"
@@ -61,11 +61,11 @@
 #include "ntqstyle.h"
 #include "ntqstring.h"
 #include "ntqregexp.h"
-#if !defined(QT_NO_CUPS) || !defined(QT_NO_NIS)
+#if !defined(TQT_NO_CUPS) || !defined(TQT_NO_NIS)
 #include "ntqlibrary.h"
 #endif
 
-#ifndef QT_NO_NIS
+#ifndef TQT_NO_NIS
 
 #ifndef BOOL_DEFINED
 #define BOOL_DEFINED
@@ -79,7 +79,7 @@
 # undef connect
 #endif
 
-#endif // QT_NO_NIS
+#endif // TQT_NO_NIS
 
 // UNIX Large File Support redefines open -> open64
 #if defined(open)
@@ -465,7 +465,7 @@ static char * parsePrintersConf( TQListView * printers, bool *found = 0 )
     return defaultPrinter;
 }
 
-#ifndef QT_NO_NIS
+#ifndef TQT_NO_NIS
 
 #if defined(Q_C_CALLBACKS)
 extern "C" {
@@ -510,7 +510,7 @@ static int retrieveNisPrinters( TQListView * printers )
     return Unavail;
 }
 
-#endif // QT_NO_NIS
+#endif // TQT_NO_NIS
 
 static char *parseNsswitchPrintersEntry( TQListView * printers, char *line )
 {
@@ -578,7 +578,7 @@ static char *parseNsswitchPrintersEntry( TQListView * printers, char *line )
 		defaultPrinter = parsePrintersConf( printers, &found );
 		if ( found )
 		    lastStatus = Success;
-#ifndef QT_NO_NIS
+#ifndef TQT_NO_NIS
 	    } else if ( source == "nis" ) {
 		lastStatus = retrieveNisPrinters( printers );
 #endif
@@ -786,7 +786,7 @@ static void parseQconfig( TQListView * printers )
 }
 
 
-#ifndef QT_NO_CUPS
+#ifndef TQT_NO_CUPS
 #include <cups/cups.h>
 
 static char * parseCupsOutput( TQListView * printers )
@@ -1037,7 +1037,7 @@ TQGroupBox * TQPrintDialog::setupDestination()
 #if defined(Q_OS_UNIX)
     char * etcLpDefault = 0;
 
-#ifndef QT_NO_CUPS
+#ifndef TQT_NO_CUPS
     etcLpDefault = parseCupsOutput( d->printers );
 #endif
     if ( d->printers->childCount() == 0 ) {
@@ -1162,7 +1162,7 @@ TQGroupBox * TQPrintDialog::setupDestination()
     horiz->addSpacing( 6 );
     d->browse = new TQPushButton( tr("Browse..."), g, "browse files" );
     d->browse->setAutoDefault( FALSE );
-#ifdef QT_NO_FILEDIALOG
+#ifdef TQT_NO_FILEDIALOG
     d->browse->setEnabled( FALSE );
 #endif
     connect( d->browse, SIGNAL(clicked()),
@@ -1372,7 +1372,7 @@ bool TQPrintDialog::getPrinterSetup( TQPrinter * p, TQWidget* w  )
 {
     if ( !globalPrintDialog ) {
 	globalPrintDialog = new TQPrintDialog( 0, 0, "global print dialog" );
-#ifndef QT_NO_WIDGET_TOPEXTRA
+#ifndef TQT_NO_WIDGET_TOPEXTRA
 	globalPrintDialog->setCaption( TQPrintDialog::tr( "Setup Printer" ) );
 #endif
 	tqAddPostRoutine( qpd_cleanup_globaldialog );
@@ -1382,7 +1382,7 @@ bool TQPrintDialog::getPrinterSetup( TQPrinter * p, TQWidget* w  )
 	globalPrintDialog->setPrinter( p, TRUE );
     }
     globalPrintDialog->adjustPosition( w );
- #ifndef QT_NO_WIDGET_TOPEXTRA
+ #ifndef TQT_NO_WIDGET_TOPEXTRA
     if ( w ) {
 	const TQPixmap *pm = w->icon();
 	if ( pm && !pm->isNull() )
@@ -1471,7 +1471,7 @@ void TQPrintDialog::setNumCopies( int copies )
 
 void TQPrintDialog::browseClicked()
 {
-#ifndef QT_NO_FILEDIALOG
+#ifndef TQT_NO_FILEDIALOG
     TQString fn = TQFileDialog::getSaveFileName( d->fileName->text(), tr( "PostScript Files (*.ps);;All Files (*)" ), this );
     if ( !fn.isNull() )
 	d->fileName->setText( fn );
