@@ -41,7 +41,7 @@
 #include "ntqprinter.h"
 #include "qprinter_p.h"
 
-#ifndef QT_NO_PRINTER
+#ifndef TQT_NO_PRINTER
 
 /*!
     \class TQPrinter ntqprinter.h
@@ -1024,5 +1024,5 @@ bool TQPrinter::isOptionEnabled( PrinterOption option )
 {
     return d->printerOptions & ( 1 << option );
 }
-#endif // QT_NO_PRINTER
+#endif // TQT_NO_PRINTER
 
