@@ -43,7 +43,7 @@
 
 #include "ntqprocess.h"
 
-#ifndef QT_NO_PROCESS
+#ifndef TQT_NO_PROCESS
 
 #include "ntqapplication.h"
 #include "private/qinternal_p.h"
@@ -352,7 +352,7 @@ void TQProcess::addArgument( const TQString& arg )
     _arguments.append( arg );
 }
 
-#ifndef QT_NO_DIR
+#ifndef TQT_NO_DIR
 /*!
     Returns the working directory that was set with
     setWorkingDirectory(), or the current directory if none has been
@@ -379,7 +379,7 @@ void TQProcess::setWorkingDirectory( const TQDir& dir )
 {
     workingDir = dir;
 }
-#endif //QT_NO_DIR
+#endif //TQT_NO_DIR
 
 /*!
     Returns the communication required with the process, i.e. some
@@ -803,4 +803,4 @@ void TQProcess::disconnectNotify( const char * )
     }
 }
 
-#endif // QT_NO_PROCESS
+#endif // TQT_NO_PROCESS
