@@ -2594,6 +2594,8 @@ void TQDns::doResInit()
     if (ns->isEmpty()) {
 #if defined(Q_MODERN_RES_API)
 	struct __res_state res;
+	/* the storage must be clean */
+	memset(&res, 0, sizeof(res));
 	res_ninit( &res );
 	int i;
 	// find the name servers to use
