@@ -199,7 +199,7 @@ TQFileInfo::TQFileInfo( const TQFile &file )
 
     \sa isRelative()
 */
-#ifndef QT_NO_DIR
+#ifndef TQT_NO_DIR
 TQFileInfo::TQFileInfo( const TQDir &d, const TQString &fileName )
 {
     fn	  = d.filePath( fileName );
@@ -332,7 +332,7 @@ void TQFileInfo::setFile( const TQFile &file )
 
     \sa isRelative()
 */
-#ifndef QT_NO_DIR
+#ifndef TQT_NO_DIR
 void TQFileInfo::setFile( const TQDir &d, const TQString &fileName )
 {
     fn	= d.filePath( fileName );
@@ -481,7 +481,7 @@ TQString TQFileInfo::extension( bool complete ) const
 
     \sa dirPath(), filePath(), fileName(), isRelative()
 */
-#ifndef QT_NO_DIR
+#ifndef TQT_NO_DIR
 TQDir TQFileInfo::dir( bool absPath ) const
 {
     return TQDir( dirPath(absPath) );
@@ -550,7 +550,7 @@ bool TQFileInfo::isHidden() const
     the path is absolute (e.g. under Unix a path is absolute if it
     begins with a "/").
 */
-#ifndef QT_NO_DIR
+#ifndef TQT_NO_DIR
 bool TQFileInfo::isRelative() const
 {
     return TQDir::isRelativePath( fn );
@@ -656,7 +656,7 @@ TQDateTime TQFileInfo::lastRead() const
     }
 }
 
-#ifndef QT_NO_DIR
+#ifndef TQT_NO_DIR
 
 /*!
     Returns the absolute path including the file name.
