@@ -39,7 +39,7 @@
 **********************************************************************/
 
 #include "ntqbuttongroup.h"
-#ifndef QT_NO_BUTTONGROUP
+#ifndef TQT_NO_BUTTONGROUP
 #include "ntqbutton.h"
 #include "ntqptrlist.h"
 #include "ntqapplication.h"
