@@ -58,7 +58,7 @@
 
 #define TQDATETIMEEDIT_HIDDEN_CHAR '0'
 
-class Q_EXPORT TQNumberSection
+class TQ_EXPORT TQNumberSection
 {
 public:
     TQNumberSection( int selStart = 0, int selEnd = 0, bool separat = TRUE, int actual = -1 )
@@ -71,7 +71,7 @@ public:
     int width() const { return selend - selstart; }
     int index() const { return act; }
     bool separator() const { return sep; }
-    Q_DUMMY_COMPARISON_OPERATOR( TQNumberSection )
+    TQ_DUMMY_COMPARISON_OPERATOR( TQNumberSection )
 private:
     int selstart :12;
     int selend	 :12;
