@@ -1148,7 +1148,7 @@ TreeMapWidget::TreeMapWidget(TreeMapItem* base,
   _needsRefresh = _base;
 
   setBackgroundMode(TQt::NoBackground);
-  setFocusPolicy(TQ_StrongFocus);
+  setFocusPolicy(TQWidget::StrongFocus);
   _tip = new TreeMapTip(this);
 }
 
@@ -1504,7 +1504,7 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
   TreeMapItem* p = _base;
   TreeMapItem* i;
 
-  if (!TQT_TQRECT_OBJECT(rect()).contains(x, y)) return 0;
+  if (!rect().contains(x, y)) return 0;
   if (DEBUG_DRAWING) kdDebug(90100) << "item(" << x << "," << y << "):" << endl;
 
   while (1) {
