@@ -40,11 +40,6 @@ DEALINGS IN THE SOFTWARE.
 #include <config.h>
 #endif
 
-// need to resolve INT32(tqglobal.h)<>INT32(Xlibint.h) conflict
-#ifndef QT_CLEAN_NAMESPACE
-#define QT_CLEAN_NAMESPACE
-#endif
-
 #include "tdestartupinfo.h"
 
 #include <unistd.h>
@@ -1135,9 +1130,9 @@ TQString TDEStartupInfoData::to_text() const
         ret += TQString::fromLatin1( " DESKTOP=%1" )
             .arg( d->desktop == NET::OnAllDesktops ? NET::OnAllDesktops : d->desktop - 1 ); // spec counts from 0
     if( !d->wmclass.isEmpty())
-        ret += TQString::fromLatin1( " WMCLASS=\"%1\"" ).arg( QString(d->wmclass) );
+        ret += TQString::fromLatin1( " WMCLASS=\"%1\"" ).arg( TQString(d->wmclass) );
     if( !d->hostname.isEmpty())
-        ret += TQString::fromLatin1( " HOSTNAME=%1" ).arg( QString(d->hostname) );
+        ret += TQString::fromLatin1( " HOSTNAME=%1" ).arg( TQString(d->hostname) );
     for( TQValueList< pid_t >::ConstIterator it = d->pids.begin();
          it != d->pids.end();
          ++it )
@@ -1461,7 +1456,7 @@ static
 TQString get_str( const TQString& item_P )
     {
     unsigned int pos = item_P.find( '=' );
-    if( item_P.length() > pos + 2 && item_P[ pos + 1 ] == (QChar)'\"' )
+    if( item_P.length() > pos + 2 && item_P[ pos + 1 ] == (TQChar)'\"' )
         {
         int pos2 = item_P.left( pos + 2 ).find( '\"' );
         if( pos2 < 0 )
@@ -1517,8 +1512,8 @@ static TQString escape_str( const TQString& str_P )
 	 pos < str_P.length();
 	 ++pos )
 	{
-	if( str_P[ pos ] == (QChar)'\\'
-	    || str_P[ pos ] == (QChar)'"' )
+	if( str_P[ pos ] == (TQChar)'\\'
+	    || str_P[ pos ] == (TQChar)'"' )
 	    ret += '\\';
 	ret += str_P[ pos ];
 	}
