@@ -28,10 +28,6 @@ DEALINGS IN THE SOFTWARE.
 #include <sys/types.h>
 #include <tqobject.h>
 
-#ifdef Q_MOC_RUN
-#define Q_WS_X11
-#endif // Q_MOC_RUN
-
 #ifdef Q_WS_X11 // FIXME(E): Redo in a less X11-specific way
 
 #include <tqcstring.h>
@@ -67,7 +63,7 @@ class TDEStartupInfoPrivate;
 class TDECORE_EXPORT TDEStartupInfo
     : public TQObject
     {
-    Q_OBJECT
+    TQ_OBJECT
     
     public:
         /**
