@@ -50,7 +50,7 @@ Value DOMObject::get(ExecState *exec, const Identifier &p) const
   }
   catch (DOM::DOMException e) {
     // ### translate code into readable string ?
-    // ### oh, and s/QString/i18n or I18N_NOOP (the code in kjs uses I18N_NOOP... but where is it translated ?)
+    // ### oh, and s/TQString/i18n or I18N_NOOP (the code in kjs uses I18N_NOOP... but where is it translated ?)
     //     and where does it appear to the user ?
     Object err = Error::create(exec, GeneralError, TQString(TQString("DOM exception %1").arg(e.code)).local8Bit());
     exec->setException( err );
@@ -327,7 +327,7 @@ TQVariant KJS::ValueToVariant(ExecState* exec, const Value &val) {
   TQVariant res;
   switch (val.type()) {
   case BooleanType:
-    res = TQVariant(val.toBoolean(exec), 0);
+    res = TQVariant(val.toBoolean(exec));
     break;
   case NumberType:
     res = TQVariant(val.toNumber(exec));
