@@ -2304,16 +2304,16 @@ void WindowQObject::timerEvent(TQTimerEvent *)
 DateTimeMS DateTimeMS::addMSecs(int s) const
 {
   DateTimeMS c = *this;
-  c.mTime = TQT_TQTIME_OBJECT(mTime.addMSecs(s));
+  c.mTime = mTime.addMSecs(s);
   if (s > 0)
   {
     if (c.mTime < mTime)
-      c.mDate = TQT_TQDATE_OBJECT(mDate.addDays(1));
+      c.mDate = mDate.addDays(1);
   }
   else
   {
     if (c.mTime > mTime)
-      c.mDate = TQT_TQDATE_OBJECT(mDate.addDays(-1));
+      c.mDate = mDate.addDays(-1);
   }
   return c;
 }
