@@ -826,7 +826,7 @@ PermissionDialog::~PermissionDialog()
 
 void PermissionDialog::clicked()
 {
-    m_button = TQT_TQOBJECT_CONST(sender())->name();
+    m_button = sender()->name();
     static_cast<const TQWidget*>(sender())->parentWidget()->close();
 }
 
