@@ -334,7 +334,7 @@ void InlineTextBox::paintShadow(TQPainter *pt, const Font *f, int _tx, int _ty,
                     m_reversed ? TQPainter::RTL : TQPainter::LTR);
 
         p.end();
-        TQImage img = TQT_TQIMAGE_OBJECT(pixmap.convertToImage()).convertDepth(32);
+        TQImage img = pixmap.convertToImage().convertDepth(32);
 
         int md = thickness*thickness; // max-dist^2
 
@@ -642,7 +642,7 @@ int InlineTextBoxArray::compareItems( Item d1, Item d2 )
     return static_cast<InlineTextBox*>(d1)->m_y - static_cast<InlineTextBox*>(d2)->m_y;
 }
 
-// remove this once TQVector::bsearch is fixed
+// remove this once TQPtrVector::bsearch is fixed
 int InlineTextBoxArray::findFirstMatching(Item d) const
 {
     int len = count();
