@@ -257,7 +257,7 @@ class BrowserExtensionPrivate;
   * to implement the virtual methods [and the standard-actions slots, see below].
   *
   * The way to associate the BrowserExtension with the part is to simply
-  * create the BrowserExtension as a child of the part (in QObject's terms).
+  * create the BrowserExtension as a child of the part (in TQObject's terms).
   * The hosting application will look for it automatically.
   *
   * Another aspect of the browser integration is that a set of standard
@@ -307,7 +307,7 @@ class BrowserExtensionPrivate;
   */
 class TDEPARTS_EXPORT BrowserExtension : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   TQ_PROPERTY( bool urlDropHandling READ isURLDropHandlingEnabled WRITE setURLDropHandlingEnabled )
 public:
   /**
@@ -723,7 +723,7 @@ private:
  */
 class TDEPARTS_EXPORT BrowserHostExtension : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   BrowserHostExtension( KParts::ReadOnlyPart *parent,
                         const char *name = 0L );
@@ -791,12 +791,12 @@ private:
  */
 class TDEPARTS_EXPORT LiveConnectExtension : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   enum Type {
       TypeVoid=0, TypeBool, TypeFunction, TypeNumber, TypeObject, TypeString
   };
-  typedef TQValueList<QPair<Type, TQString> > ArgList;
+  typedef TQValueList<TQPair<Type, TQString> > ArgList;
 
   LiveConnectExtension( KParts::ReadOnlyPart *parent, const char *name = 0L );
 
