@@ -493,7 +493,7 @@ void KMMainView::slotRightButtonClicked(const TQString& prname, const TQPoint& p
 
 void KMMainView::slotChangePrinterState()
 {
-	TQString	opname = TQT_TQOBJECT_CONST(sender())->name();
+	TQString	opname = sender()->name();
 	if (m_current && opname.startsWith("printer_"))
 	{
 		opname = opname.mid(8);
