@@ -599,12 +599,12 @@ void FaxCtrl::slotClearLog()
 
 void FaxCtrl::slotCloseLog()
 {
-	const TQObject	*obj = TQT_TQOBJECT_CONST(sender());
+	const TQObject	*obj = sender();
 	if (m_logview)
 	{
 		TQTextEdit	*view = m_logview;
 		m_logview = 0;
-		if (obj && obj->inherits(TQPUSHBUTTON_OBJECT_NAME_STRING))
+		if (obj && obj->inherits("TQPushButton"))
 			delete view->parentWidget();
 kdDebug() << "slotClose()" << endl;
 	}
