@@ -32,7 +32,7 @@ namespace KNotes {
 
 class KDE_EXPORT ResourceXMLRPCConfig : public KRES::ConfigWidget
 { 
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
