@@ -536,7 +536,7 @@ bool KJanusWidget::setSwallowedWidget( TQWidget *widget )
   }
   else
   {
-    if( TQT_BASE_OBJECT(widget->parent()) != TQT_BASE_OBJECT(mSwallowPage) )
+    if( widget->parent() != mSwallowPage )
     {
       widget->reparent( mSwallowPage, 0, TQPoint(0,0) );
     }
@@ -684,7 +684,7 @@ int KJanusWidget::pageIndex( TQWidget *widget ) const
     // and addGridPage() but not with addPage() which returns a child of
     // the toplevel page. addPage() returns a TQFrame so I check for that.
     //
-    if( widget->isA(TQFRAME_OBJECT_NAME_STRING) )
+    if( widget->isA("TQFrame") )
     {
       return d->mPageToInt[widget->parentWidget()];
     }
@@ -726,7 +726,7 @@ void KJanusWidget::slotItemClicked(TQListViewItem *it)
     it->setOpen(!it->isOpen());
 }
 
-// hack because qt does not support Q_OBJECT in nested classes
+// hack because qt does not support TQ_OBJECT in nested classes
 void KJanusWidget::slotOnItem(TQListBoxItem *qitem)
 {
   mIconList->slotOnItem( qitem );
@@ -1017,7 +1017,7 @@ void KJanusWidget::IconListBox::leaveEvent( TQEvent *ev )
   }
 } 
 
-// hack because qt does not support Q_OBJECT in nested classes
+// hack because qt does not support TQ_OBJECT in nested classes
 void KJanusWidget::IconListBox::slotOnItem(TQListBoxItem *qitem)
 {
   TDEListBox::slotOnItem( qitem );
