@@ -146,7 +146,7 @@ class TDEUI_EXPORT KLineEdit : public TQLineEdit, public TDECompletionBase
 {
     friend class KComboBox;
 
-    Q_OBJECT
+    TQ_OBJECT
     TQ_PROPERTY( bool contextMenuEnabled READ isContextMenuEnabled WRITE setContextMenuEnabled )
     TQ_PROPERTY( bool urlDropsEnabled READ isURLDropsEnabled WRITE setURLDropsEnabled )
     TQ_PROPERTY( bool trapEnterKeyEvent READ trapReturnKey WRITE setTrapReturnKey )
