@@ -310,7 +310,7 @@ bool QXEmbedAppFilter::eventFilter( TQObject *o, TQEvent * e)
         //        active and has just been given the Qt focus (L0614) or
         //        because the widget already had the Qt focus and just became
         //        active (L0615).
-        if ( TQT_BASE_OBJECT(tqApp->focusWidget()) == TQT_BASE_OBJECT(o) &&
+        if ( tqApp->focusWidget() == o &&
              ((QPublicWidget*)tqApp->focusWidget()->topLevelWidget())->topData()->embedded ) {
             TQFocusEvent* fe = (TQFocusEvent*) e;
             if ( obeyFocus || fe->reason() != TQFocusEvent::ActiveWindow /*|| fe->reason() == TQFocusEvent::Mouse ||
@@ -319,11 +319,7 @@ bool QXEmbedAppFilter::eventFilter( TQObject *o, TQEvent * e)
                 //        Variable `obeyFocus' suggests that this is the result of mouse
                 //        activity in the client.  The XEMBED_REQUEST_FOCUS message causes
                 //        the embedding widget to take the Qt focus (L2085).
-#ifdef USE_QT4
-                WId window = ((QPublicWidget*)tqApp->focusWidget()->topLevelWidget())->effectiveWinId();
-#else // USE_QT4
                 WId window = ((QPublicWidget*)tqApp->focusWidget()->topLevelWidget())->topData()->parentWinId;
-#endif // USE_QT4
                 focusMap->remove( tqApp->focusWidget()->topLevelWidget() );
                 sendXEmbedMessage( window, XEMBED_REQUEST_FOCUS );
             } else if ( fe->reason() == TQFocusEvent::ActiveWindow ) {
@@ -344,7 +340,7 @@ bool QXEmbedAppFilter::eventFilter( TQObject *o, TQEvent * e)
         }
         break;
     case TQEvent::KeyPress: 
-        if (TQT_BASE_OBJECT(tqApp->focusWidget()) == TQT_BASE_OBJECT(o) &&
+        if (tqApp->focusWidget() == o &&
             ((QPublicWidget*)tqApp->focusWidget()->topLevelWidget())->topData()->embedded ) {
             // L0620: The following code replaces the Qt code that 
             //        handles focus focus changes with the tab key. See the
@@ -365,32 +361,20 @@ bool QXEmbedAppFilter::eventFilter( TQObject *o, TQEvent * e)
             bool tabForward = true;
             if ( !(k->state() & ControlButton || k->state() & AltButton) ) {
                 if ( k->key() == Key_Backtab || (k->key() == Key_Tab && (k->state() & ShiftButton)) ) {
-#ifdef USE_QT4
-                    res = ((QPublicWidget*)w)->focusNextPrev( tabForward = false );
-#else // USE_QT4
                     TQFocusEvent::setReason( TQFocusEvent::Backtab );
                     res = ((QPublicWidget*)w)->focusNextPrev( tabForward = false );
                     TQFocusEvent::resetReason();
-#endif // USE_QT4
                 } else if ( k->key() == Key_Tab ) {
-#ifdef USE_QT4
-                    res = ((QPublicWidget*)w)->focusNextPrev( tabForward = true );
-#else // USE_QT4
                     TQFocusEvent::setReason( TQFocusEvent::Tab );
                     res = ((QPublicWidget*)w)->focusNextPrev( tabForward = true );
                     TQFocusEvent::resetReason();
-#endif // USE_QT4
                 }
             }
             if (res) {
                 // L0625: We changed the focus because of tab/backtab key
                 //        Now check whether we have been looping around.
                 TQFocusData *fd = ((QPublicWidget*)w)->focusData();
-#ifdef USE_QT4
-                WId window = ((QPublicWidget*)w->topLevelWidget())->effectiveWinId();
-#else // USE_QT4
                 WId window = ((QPublicWidget*)w->topLevelWidget())->topData()->parentWinId;
-#endif // USE_QT4
                 TQWidget *cw = 0;
                 TQWidget *fw = fd->home();
                 if (tabForward && window) {
@@ -445,12 +429,7 @@ static int qxembed_x11_event_filter( XEvent* e)
                 // L0675: We just have been embedded into a XEMBED aware widget.
                 TQTLWExtra *extra = ((QPublicWidget*)w->topLevelWidget())->topData();
                 extra->embedded = 1;
-#ifdef USE_QT4
-                // [FIXME]
-                printf("[FIXME] WId not set in tdelibs/tdeui/qxembed.cpp\n");
-#else // USE_QT4
                 extra->parentWinId = e->xclient.data.l[3];
-#endif // USE_QT4
                 w->topLevelWidget()->show();
                 break;
             }
@@ -509,29 +488,19 @@ static int qxembed_x11_event_filter( XEvent* e)
                     case XEMBED_FOCUS_FIRST:
                         {
                             // L0684: Search first widget in tab chain
-#ifdef USE_QT4
-                            w->topLevelWidget()->setFocus();
-                            ((QPublicWidget*)w->topLevelWidget())->focusNextPrev(true);
-#else // USE_QT4
                             TQFocusEvent::setReason( TQFocusEvent::Tab );
                             w->topLevelWidget()->setFocus();
                             ((QPublicWidget*)w->topLevelWidget())->focusNextPrev(true);
                             TQFocusEvent::resetReason();
-#endif // USE_QT4
                         }
                         break;
                     case XEMBED_FOCUS_LAST:
                         {
                             // L0686: Search last widget in tab chain
-#ifdef USE_QT4
-                            w->topLevelWidget()->setFocus();
-                            ((QPublicWidget*)w->topLevelWidget())->focusNextPrev(false);
-#else // USE_QT4
                             TQFocusEvent::setReason( TQFocusEvent::Backtab );
                             w->topLevelWidget()->setFocus();
                             ((QPublicWidget*)w->topLevelWidget())->focusNextPrev(false);
                             TQFocusEvent::resetReason();
-#endif // USE_QT4
                         }
                         break;
                     default:
@@ -661,7 +630,7 @@ QXEmbed::QXEmbed(TQWidget *parent, const char *name, WFlags f)
     //        See L0660, L0671, L0685.
     initialize();
     window = 0;
-    setFocusPolicy(TQ_StrongFocus);
+    setFocusPolicy(TQWidget::StrongFocus);
     setKeyCompression( false );
 
     // L0910: Trick Qt to create extraData();
@@ -810,7 +779,7 @@ bool QXEmbed::eventFilter( TQObject *o, TQEvent * e)
 
     switch ( e->type() ) {
     case TQEvent::WindowActivate:
-        if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(topLevelWidget()) ) {
+        if ( o == topLevelWidget() ) {
             // L1310: Qt thinks the application window has just been activated.
             //        Make sure the X11 focus is on the focus proxy window. See L0686.
             if ( !((QPublicWidget*) topLevelWidget())->topData()->embedded )
@@ -826,7 +795,7 @@ bool QXEmbed::eventFilter( TQObject *o, TQEvent * e)
         }
         break;
     case TQEvent::WindowDeactivate:
-        if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(topLevelWidget()) ) {
+        if ( o == topLevelWidget() ) {
             if (d->xplain)
                 // L1321: Activation has changed. Grab state might change. See L2800.
                 checkGrab();
@@ -838,9 +807,9 @@ bool QXEmbed::eventFilter( TQObject *o, TQEvent * e)
     case TQEvent::Move:
         {
             TQWidget* pos = this;
-            while( TQT_BASE_OBJECT(pos) != TQT_BASE_OBJECT(o) && TQT_BASE_OBJECT(pos) != TQT_BASE_OBJECT(topLevelWidget()))
+            while( pos != o && pos != topLevelWidget())
                 pos = pos->parentWidget();
-            if( TQT_BASE_OBJECT(pos) == TQT_BASE_OBJECT(o) ) {
+            if( pos == o ) {
                 // L1390: Send fake configure notify events whenever the
                 //        global position of the client changes. See L2900.
                 TQPoint globalPos = mapToGlobal(TQPoint(0,0));
@@ -1168,13 +1137,9 @@ bool QXEmbed::x11Event( XEvent* e)
         if (d->xplain && d->xgrab) {
             // L2060: The passive grab has intercepted a mouse click
             //        in the embedded client window. Take the focus.
-#ifdef USE_QT4
-            setFocus();
-#else // USE_QT4
             TQFocusEvent::setReason( TQFocusEvent::Mouse );
             setFocus();
             TQFocusEvent::resetReason();
-#endif // USE_QT4
             // L2064: Resume X11 event processing.
             XAllowEvents(tqt_xdisplay(), ReplayPointer, CurrentTime);
             // L2065: Qt should not know about this.
@@ -1213,20 +1178,12 @@ bool QXEmbed::x11Event( XEvent* e)
                 if( ((QPublicWidget*)topLevelWidget())->topData()->embedded ) {
                     focusMap->remove( topLevelWidget() );
                     focusMap->insert( topLevelWidget(), new TQGuardedPtr<TQWidget>( this ));
-#ifdef USE_QT4
-                    WId window = ((QPublicWidget*)topLevelWidget())->effectiveWinId();
-#else // USE_QT4
                     WId window = ((QPublicWidget*)topLevelWidget())->topData()->parentWinId;
-#endif // USE_QT4
                     sendXEmbedMessage( window, XEMBED_REQUEST_FOCUS );
                 } else {
-#ifdef USE_QT4
-                    setFocus();
-#else // USE_QT4
                     TQFocusEvent::setReason( TQFocusEvent::Mouse );
                     setFocus();
                     TQFocusEvent::resetReason();
-#endif // USE_QT4
                 }
                 break;
             default:
@@ -1318,12 +1275,7 @@ void QXEmbed::embedClientIntoWindow(TQWidget* client, WId window)
     XReparentWindow(tqt_xdisplay(), client->winId(), window, 0, 0);
     // L2451: These two lines are redundant. See L0680.
     ((QXEmbed*)client)->topData()->embedded = true;
-#ifdef USE_QT4
-    // [FIXME]
-    printf("[FIXME] WId not set in tdelibs/tdeui/qxembed.cpp\n");
-#else // USE_QT4
     ((QXEmbed*)client)->topData()->parentWinId = window;
-#endif // USE_QT4
     // L2452: This seems redundant because L2020 maps the window.
     //        But calling show() might also set Qt internal flags.
     client->show();
