@@ -753,7 +753,7 @@ void FlatButton::init()
 	setUsesBigPixmap(true);
 	setAutoRaise(true);
 	setTextPosition( TQToolButton::Under );
-	setFocusPolicy(TQ_StrongFocus);	
+	setFocusPolicy(TQWidget::StrongFocus);	
  }
 
 
