@@ -1175,7 +1175,7 @@ void MainWindow::projectInsertFile()
     fileOpen( "", "" );
 }
 
-Q_EXPORT void MainWindow::fileOpen( const TQString &filter, const TQString &extension, const TQString &fn, bool inProject  )
+TQ_EXPORT void MainWindow::fileOpen( const TQString &filter, const TQString &extension, const TQString &fn, bool inProject  )
 {
     statusBar()->message( tr( "Open a file...") );
 
@@ -1278,7 +1278,7 @@ Q_EXPORT void MainWindow::fileOpen( const TQString &filter, const TQString &exte
     }
 }
 
-Q_EXPORT FormWindow *MainWindow::openFormWindow( const TQString &filename, bool validFileName, FormFile *ff )
+TQ_EXPORT FormWindow *MainWindow::openFormWindow( const TQString &filename, bool validFileName, FormFile *ff )
 {
     if ( filename.isEmpty() )
 	return 0;
