@@ -185,7 +185,7 @@ public:
     TQString id;
     ChoiceItem(const TQString& i, TQListViewItem* parent) :
 	TQCheckListItem(parent,
-	    i.mid(6), // strip "QT_NO_" as we reverse the logic
+	    i.mid(6), // strip "TQT_NO_" as we reverse the logic
 	    CheckBox),
 	id(i)
     {
@@ -331,7 +331,7 @@ void Main::save()
 
 void Main::testAll()
 {
-    TQString qtdir = getenv("QTDIR");
+    TQString qtdir = getenv("TQTDIR");
     chdir((qtdir+"/src").ascii());
     TQString c;
     for (TQStringList::ConstIterator it = choices.begin(); it != choices.end(); ++it)
@@ -388,7 +388,7 @@ template <class K, class D>
 TQValueList<K> keys(TQMap<K,D> map)
 {
     TQValueList<K> result;
-    for (Q_TYPENAME TQMap<K,D>::ConstIterator it = map.begin(); it!=map.end(); ++it)
+    for (TQ_TYPENAME TQMap<K,D>::ConstIterator it = map.begin(); it!=map.end(); ++it)
 	result.append(it.key());
     return result;
 }
@@ -402,7 +402,7 @@ void Main::loadFeatures(const TQString& filename)
 	return;
     }
     TQTextStream s(&file);
-    TQRegExp qt_no_xxx("QT_NO_[A-Z_0-9]*");
+    TQRegExp qt_no_xxx("TQT_NO_[A-Z_0-9]*");
     TQStringList sections;
 
 #if 1
@@ -569,7 +569,7 @@ void Main::loadConfig(const TQString& filename)
 	return;
     }
     TQTextStream s(&file);
-    TQRegExp qt_no_xxx("QT_NO_[A-Z_0-9]*");
+    TQRegExp qt_no_xxx("TQT_NO_[A-Z_0-9]*");
 
     for (TQStringList::Iterator ch = choices.begin(); ch != choices.end(); ++ch) {
 	item[*ch]->setDefined(FALSE);
@@ -712,7 +712,7 @@ int main(int argc, char** argv)
 {
     TQApplication app(argc,argv);
     Main m;
-    TQString qtdir = getenv("QTDIR");
+    TQString qtdir = getenv("TQTDIR");
     TQString qfeatures = qtdir + "/src/tools/qfeatures.txt";
     //TQString qfeatures = qtdir + "/include/ntqfeatures.h";
     TQString qconfig = qtdir + "/include/ntqconfig.h";
