@@ -60,7 +60,7 @@
 
 // from qapplication.cpp and qapplication_x11.cpp - These are NOT for
 // external use ignore them
-extern bool Q_EXPORT tqt_resolve_symlinks;
+extern bool TQ_EXPORT tqt_resolve_symlinks;
 
 
 static const char *appearance_text =
