@@ -1487,7 +1487,7 @@ to
     </message>
 </context>
 <context>
-    <name>QObject</name>
+    <name>TQObject</name>
     <message>
         <source>On The Spot</source>
         <translation></translation>
