@@ -134,6 +134,9 @@ TQString GlowClientGlobals::getPixmapName(PixmapType type, bool isActive)
 GlowClientGlobals::GlowClientGlobals()
 	: KDecorationFactory()
 {
+	TDEGlobal::locale()->insertCatalogue("twin_clients");
+	TDEGlobal::locale()->insertCatalogue("twin_art_clients");
+
 	_button_factory = new GlowButtonFactory();
 	readConfig();
 	readTheme ();
@@ -857,7 +860,7 @@ void GlowClient::slotMaximize()
 
 bool GlowClient::eventFilter( TQObject* o, TQEvent* e )
 {
-	if( TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(widget()))
+	if( o != widget())
 		return false;
 	switch( e->type())
 	{
