@@ -153,6 +153,9 @@ bool validPixmaps( TQPixmap* p[] )
 
 ThemeHandler::ThemeHandler()
 {
+	TDEGlobal::locale()->insertCatalogue("twin_clients");
+	TDEGlobal::locale()->insertCatalogue("twin_art_clients");
+
 	initialized = false;
 
 	// Prevent having globals objects (use pointers to objects)
@@ -1661,7 +1664,7 @@ void IceWMClient::menuButtonReleased()
 
 bool IceWMClient::eventFilter( TQObject* o, TQEvent* e )
 {
-	if( TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(widget()))
+	if( o != widget())
 	return false;
 	switch( e->type())
 	{
@@ -1699,5 +1702,3 @@ extern "C"
 
 
 #include "icewm.moc"
-
-// vim: ts=4
