@@ -51,7 +51,7 @@ public:
      * These values represent positions inside an area
      */
     enum Position
-        { // without prefix, they'd conflict with Qt::TopLeft etc. :(
+        { // without prefix, they'd conflict with TQt::TopLeft etc. :(
         PositionCenter         = 0x00,
         PositionLeft           = 0x01,
         PositionRight          = 0x02,
@@ -313,7 +313,7 @@ protected:
 class KWIN_EXPORT KDecoration
     : public TQObject, public KDecorationDefines
     {
-    Q_OBJECT
+    TQ_OBJECT
     public:
 	/**
 	 * Constructs a KDecoration object. Both the arguments are passed from
